from __future__ import annotations

# pylint: disable=too-many-lines
types: list[str] = [
    "AWS::ACMPCA::Certificate",
    "AWS::ACMPCA::CertificateAuthority",
    "AWS::ACMPCA::CertificateAuthorityActivation",
    "AWS::ACMPCA::Permission",
    "AWS::APS::Workspace",
    "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
    "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
    "AWS::AccessAnalyzer::Analyzer",
    "AWS::AmazonMQ::Broker",
    "AWS::AmazonMQ::Configuration",
    "AWS::AmazonMQ::ConfigurationAssociation",
    "AWS::Amplify::App",
    "AWS::Amplify::Branch",
    "AWS::Amplify::Domain",
    "AWS::AmplifyUIBuilder::Component",
    "AWS::AmplifyUIBuilder::Form",
    "AWS::AmplifyUIBuilder::Theme",
    "AWS::ApiGateway::Account",
    "AWS::ApiGateway::ApiKey",
    "AWS::ApiGateway::Authorizer",
    "AWS::ApiGateway::BasePathMapping",
    "AWS::ApiGateway::BasePathMappingV2",
    "AWS::ApiGateway::ClientCertificate",
    "AWS::ApiGateway::Deployment",
    "AWS::ApiGateway::DocumentationPart",
    "AWS::ApiGateway::DocumentationVersion",
    "AWS::ApiGateway::DomainName",
    "AWS::ApiGateway::DomainNameAccessAssociation",
    "AWS::ApiGateway::DomainNameV2",
    "AWS::ApiGateway::GatewayResponse",
    "AWS::ApiGateway::Method",
    "AWS::ApiGateway::Model",
    "AWS::ApiGateway::RequestValidator",
    "AWS::ApiGateway::Resource",
    "AWS::ApiGateway::RestApi",
    "AWS::ApiGateway::Stage",
    "AWS::ApiGateway::UsagePlan",
    "AWS::ApiGateway::UsagePlanKey",
    "AWS::ApiGateway::VpcLink",
    "AWS::ApiGatewayV2::Api",
    "AWS::ApiGatewayV2::ApiGatewayManagedOverrides",
    "AWS::ApiGatewayV2::ApiMapping",
    "AWS::ApiGatewayV2::Authorizer",
    "AWS::ApiGatewayV2::Deployment",
    "AWS::ApiGatewayV2::DomainName",
    "AWS::ApiGatewayV2::Integration",
    "AWS::ApiGatewayV2::IntegrationResponse",
    "AWS::ApiGatewayV2::Model",
    "AWS::ApiGatewayV2::Route",
    "AWS::ApiGatewayV2::RouteResponse",
    "AWS::ApiGatewayV2::Stage",
    "AWS::ApiGatewayV2::VpcLink",
    "AWS::AppConfig::Application",
    "AWS::AppConfig::ConfigurationProfile",
    "AWS::AppConfig::Deployment",
    "AWS::AppConfig::DeploymentStrategy",
    "AWS::AppConfig::Environment",
    "AWS::AppConfig::Extension",
    "AWS::AppConfig::ExtensionAssociation",
    "AWS::AppConfig::HostedConfigurationVersion",
    "AWS::AppFlow::Connector",
    "AWS::AppFlow::ConnectorProfile",
    "AWS::AppFlow::Flow",
    "AWS::AppIntegrations::Application",
    "AWS::AppIntegrations::DataIntegration",
    "AWS::AppIntegrations::EventIntegration",
    "AWS::AppMesh::GatewayRoute",
    "AWS::AppMesh::Mesh",
    "AWS::AppMesh::Route",
    "AWS::AppMesh::VirtualGateway",
    "AWS::AppMesh::VirtualNode",
    "AWS::AppMesh::VirtualRouter",
    "AWS::AppMesh::VirtualService",
    "AWS::AppStream::AppBlock",
    "AWS::AppStream::AppBlockBuilder",
    "AWS::AppStream::Application",
    "AWS::AppStream::ApplicationEntitlementAssociation",
    "AWS::AppStream::ApplicationFleetAssociation",
    "AWS::AppStream::DirectoryConfig",
    "AWS::AppStream::Entitlement",
    "AWS::AppStream::Fleet",
    "AWS::AppStream::ImageBuilder",
    "AWS::AppStream::Stack",
    "AWS::AppStream::StackFleetAssociation",
    "AWS::AppStream::StackUserAssociation",
    "AWS::AppStream::User",
    "AWS::AppSync::Api",
    "AWS::AppSync::ApiCache",
    "AWS::AppSync::ApiKey",
    "AWS::AppSync::ChannelNamespace",
    "AWS::AppSync::DataSource",
    "AWS::AppSync::DomainName",
    "AWS::AppSync::DomainNameApiAssociation",
    "AWS::AppSync::FunctionConfiguration",
    "AWS::AppSync::GraphQLApi",
    "AWS::AppSync::GraphQLSchema",
    "AWS::AppSync::Resolver",
    "AWS::AppSync::SourceApiAssociation",
    "AWS::ApplicationAutoScaling::ScalableTarget",
    "AWS::ApplicationAutoScaling::ScalingPolicy",
    "AWS::ApplicationInsights::Application",
    "AWS::ApplicationSignals::Discovery",
    "AWS::ApplicationSignals::ServiceLevelObjective",
    "AWS::Athena::DataCatalog",
    "AWS::Athena::NamedQuery",
    "AWS::Athena::PreparedStatement",
    "AWS::Athena::WorkGroup",
    "AWS::AuditManager::Assessment",
    "AWS::AutoScaling::AutoScalingGroup",
    "AWS::AutoScaling::LaunchConfiguration",
    "AWS::AutoScaling::LifecycleHook",
    "AWS::AutoScaling::ScalingPolicy",
    "AWS::AutoScaling::ScheduledAction",
    "AWS::AutoScaling::WarmPool",
    "AWS::AutoScalingPlans::ScalingPlan",
    "AWS::Backup::BackupPlan",
    "AWS::Backup::BackupSelection",
    "AWS::Backup::BackupVault",
    "AWS::Backup::Framework",
    "AWS::Backup::LogicallyAirGappedBackupVault",
    "AWS::Backup::ReportPlan",
    "AWS::Backup::RestoreTestingPlan",
    "AWS::Backup::RestoreTestingSelection",
    "AWS::BackupGateway::Hypervisor",
    "AWS::Batch::ComputeEnvironment",
    "AWS::Batch::ConsumableResource",
    "AWS::Batch::JobDefinition",
    "AWS::Batch::JobQueue",
    "AWS::Batch::SchedulingPolicy",
    "AWS::Bedrock::Agent",
    "AWS::Bedrock::AgentAlias",
    "AWS::Bedrock::ApplicationInferenceProfile",
    "AWS::Bedrock::DataSource",
    "AWS::Bedrock::Flow",
    "AWS::Bedrock::FlowAlias",
    "AWS::Bedrock::FlowVersion",
    "AWS::Bedrock::Guardrail",
    "AWS::Bedrock::GuardrailVersion",
    "AWS::Bedrock::KnowledgeBase",
    "AWS::Bedrock::Prompt",
    "AWS::Bedrock::PromptVersion",
    "AWS::Budgets::Budget",
    "AWS::Budgets::BudgetsAction",
    "AWS::CDK::Metadata",
    "AWS::CE::AnomalyMonitor",
    "AWS::CE::AnomalySubscription",
    "AWS::CE::CostCategory",
    "AWS::Cassandra::Keyspace",
    "AWS::Cassandra::Table",
    "AWS::Cassandra::Type",
    "AWS::CertificateManager::Account",
    "AWS::CertificateManager::Certificate",
    "AWS::Chatbot::CustomAction",
    "AWS::Chatbot::MicrosoftTeamsChannelConfiguration",
    "AWS::Chatbot::SlackChannelConfiguration",
    "AWS::Cloud9::EnvironmentEC2",
    "AWS::CloudFormation::CustomResource",
    "AWS::CloudFormation::GuardHook",
    "AWS::CloudFormation::HookDefaultVersion",
    "AWS::CloudFormation::HookTypeConfig",
    "AWS::CloudFormation::HookVersion",
    "AWS::CloudFormation::LambdaHook",
    "AWS::CloudFormation::Macro",
    "AWS::CloudFormation::ModuleDefaultVersion",
    "AWS::CloudFormation::ModuleVersion",
    "AWS::CloudFormation::PublicTypeVersion",
    "AWS::CloudFormation::Publisher",
    "AWS::CloudFormation::ResourceDefaultVersion",
    "AWS::CloudFormation::ResourceVersion",
    "AWS::CloudFormation::Stack",
    "AWS::CloudFormation::StackSet",
    "AWS::CloudFormation::TypeActivation",
    "AWS::CloudFormation::WaitCondition",
    "AWS::CloudFormation::WaitConditionHandle",
    "AWS::CloudFront::AnycastIpList",
    "AWS::CloudFront::CachePolicy",
    "AWS::CloudFront::CloudFrontOriginAccessIdentity",
    "AWS::CloudFront::ConnectionGroup",
    "AWS::CloudFront::ContinuousDeploymentPolicy",
    "AWS::CloudFront::Distribution",
    "AWS::CloudFront::DistributionTenant",
    "AWS::CloudFront::Function",
    "AWS::CloudFront::KeyGroup",
    "AWS::CloudFront::KeyValueStore",
    "AWS::CloudFront::MonitoringSubscription",
    "AWS::CloudFront::OriginAccessControl",
    "AWS::CloudFront::OriginRequestPolicy",
    "AWS::CloudFront::PublicKey",
    "AWS::CloudFront::RealtimeLogConfig",
    "AWS::CloudFront::ResponseHeadersPolicy",
    "AWS::CloudFront::StreamingDistribution",
    "AWS::CloudFront::VpcOrigin",
    "AWS::CloudTrail::Channel",
    "AWS::CloudTrail::Dashboard",
    "AWS::CloudTrail::EventDataStore",
    "AWS::CloudTrail::ResourcePolicy",
    "AWS::CloudTrail::Trail",
    "AWS::CloudWatch::Alarm",
    "AWS::CloudWatch::AnomalyDetector",
    "AWS::CloudWatch::CompositeAlarm",
    "AWS::CloudWatch::Dashboard",
    "AWS::CloudWatch::InsightRule",
    "AWS::CloudWatch::MetricStream",
    "AWS::CodeBuild::Project",
    "AWS::CodeBuild::ReportGroup",
    "AWS::CodeBuild::SourceCredential",
    "AWS::CodeCommit::Repository",
    "AWS::CodeConnections::Connection",
    "AWS::CodeDeploy::Application",
    "AWS::CodeDeploy::DeploymentConfig",
    "AWS::CodeDeploy::DeploymentGroup",
    "AWS::CodePipeline::CustomActionType",
    "AWS::CodePipeline::Pipeline",
    "AWS::CodePipeline::Webhook",
    "AWS::CodeStar::GitHubRepository",
    "AWS::CodeStarConnections::Connection",
    "AWS::CodeStarConnections::RepositoryLink",
    "AWS::CodeStarConnections::SyncConfiguration",
    "AWS::CodeStarNotifications::NotificationRule",
    "AWS::Cognito::IdentityPool",
    "AWS::Cognito::IdentityPoolPrincipalTag",
    "AWS::Cognito::IdentityPoolRoleAttachment",
    "AWS::Cognito::LogDeliveryConfiguration",
    "AWS::Cognito::ManagedLoginBranding",
    "AWS::Cognito::UserPool",
    "AWS::Cognito::UserPoolClient",
    "AWS::Cognito::UserPoolDomain",
    "AWS::Cognito::UserPoolGroup",
    "AWS::Cognito::UserPoolIdentityProvider",
    "AWS::Cognito::UserPoolResourceServer",
    "AWS::Cognito::UserPoolRiskConfigurationAttachment",
    "AWS::Cognito::UserPoolUICustomizationAttachment",
    "AWS::Cognito::UserPoolUser",
    "AWS::Cognito::UserPoolUserToGroupAttachment",
    "AWS::Comprehend::DocumentClassifier",
    "AWS::Comprehend::Flywheel",
    "AWS::Config::AggregationAuthorization",
    "AWS::Config::ConfigRule",
    "AWS::Config::ConfigurationAggregator",
    "AWS::Config::ConfigurationRecorder",
    "AWS::Config::ConformancePack",
    "AWS::Config::DeliveryChannel",
    "AWS::Config::OrganizationConfigRule",
    "AWS::Config::OrganizationConformancePack",
    "AWS::Config::RemediationConfiguration",
    "AWS::Config::StoredQuery",
    "AWS::Connect::AgentStatus",
    "AWS::Connect::ApprovedOrigin",
    "AWS::Connect::ContactFlow",
    "AWS::Connect::ContactFlowModule",
    "AWS::Connect::ContactFlowVersion",
    "AWS::Connect::EmailAddress",
    "AWS::Connect::EvaluationForm",
    "AWS::Connect::HoursOfOperation",
    "AWS::Connect::Instance",
    "AWS::Connect::InstanceStorageConfig",
    "AWS::Connect::IntegrationAssociation",
    "AWS::Connect::PhoneNumber",
    "AWS::Connect::PredefinedAttribute",
    "AWS::Connect::Prompt",
    "AWS::Connect::Queue",
    "AWS::Connect::QuickConnect",
    "AWS::Connect::RoutingProfile",
    "AWS::Connect::Rule",
    "AWS::Connect::SecurityKey",
    "AWS::Connect::SecurityProfile",
    "AWS::Connect::TaskTemplate",
    "AWS::Connect::User",
    "AWS::Connect::UserHierarchyGroup",
    "AWS::Connect::UserHierarchyStructure",
    "AWS::Connect::View",
    "AWS::Connect::ViewVersion",
    "AWS::ConnectCampaigns::Campaign",
    "AWS::ConnectCampaignsV2::Campaign",
    "AWS::ControlTower::EnabledBaseline",
    "AWS::ControlTower::EnabledControl",
    "AWS::ControlTower::LandingZone",
    "AWS::CustomerProfiles::CalculatedAttributeDefinition",
    "AWS::CustomerProfiles::Domain",
    "AWS::CustomerProfiles::EventStream",
    "AWS::CustomerProfiles::EventTrigger",
    "AWS::CustomerProfiles::Integration",
    "AWS::CustomerProfiles::ObjectType",
    "AWS::CustomerProfiles::SegmentDefinition",
    "AWS::DLM::LifecyclePolicy",
    "AWS::DMS::Certificate",
    "AWS::DMS::DataMigration",
    "AWS::DMS::DataProvider",
    "AWS::DMS::Endpoint",
    "AWS::DMS::EventSubscription",
    "AWS::DMS::InstanceProfile",
    "AWS::DMS::MigrationProject",
    "AWS::DMS::ReplicationConfig",
    "AWS::DMS::ReplicationInstance",
    "AWS::DMS::ReplicationSubnetGroup",
    "AWS::DMS::ReplicationTask",
    "AWS::DataBrew::Dataset",
    "AWS::DataBrew::Job",
    "AWS::DataBrew::Project",
    "AWS::DataBrew::Recipe",
    "AWS::DataBrew::Ruleset",
    "AWS::DataBrew::Schedule",
    "AWS::DataPipeline::Pipeline",
    "AWS::DataSync::Agent",
    "AWS::DataSync::LocationAzureBlob",
    "AWS::DataSync::LocationEFS",
    "AWS::DataSync::LocationFSxLustre",
    "AWS::DataSync::LocationFSxONTAP",
    "AWS::DataSync::LocationFSxOpenZFS",
    "AWS::DataSync::LocationFSxWindows",
    "AWS::DataSync::LocationHDFS",
    "AWS::DataSync::LocationNFS",
    "AWS::DataSync::LocationObjectStorage",
    "AWS::DataSync::LocationS3",
    "AWS::DataSync::LocationSMB",
    "AWS::DataSync::StorageSystem",
    "AWS::DataSync::Task",
    "AWS::DataZone::Connection",
    "AWS::DataZone::DataSource",
    "AWS::DataZone::Domain",
    "AWS::DataZone::Environment",
    "AWS::DataZone::EnvironmentActions",
    "AWS::DataZone::EnvironmentBlueprintConfiguration",
    "AWS::DataZone::EnvironmentProfile",
    "AWS::DataZone::GroupProfile",
    "AWS::DataZone::Project",
    "AWS::DataZone::ProjectMembership",
    "AWS::DataZone::SubscriptionTarget",
    "AWS::DataZone::UserProfile",
    "AWS::Detective::Graph",
    "AWS::Detective::MemberInvitation",
    "AWS::Detective::OrganizationAdmin",
    "AWS::DevOpsGuru::LogAnomalyDetectionIntegration",
    "AWS::DevOpsGuru::NotificationChannel",
    "AWS::DevOpsGuru::ResourceCollection",
    "AWS::DirectoryService::MicrosoftAD",
    "AWS::DirectoryService::SimpleAD",
    "AWS::DocDB::DBCluster",
    "AWS::DocDB::DBClusterParameterGroup",
    "AWS::DocDB::DBInstance",
    "AWS::DocDB::DBSubnetGroup",
    "AWS::DocDB::EventSubscription",
    "AWS::DocDBElastic::Cluster",
    "AWS::DynamoDB::GlobalTable",
    "AWS::DynamoDB::Table",
    "AWS::EC2::CapacityReservation",
    "AWS::EC2::CapacityReservationFleet",
    "AWS::EC2::CarrierGateway",
    "AWS::EC2::ClientVpnAuthorizationRule",
    "AWS::EC2::ClientVpnEndpoint",
    "AWS::EC2::ClientVpnRoute",
    "AWS::EC2::ClientVpnTargetNetworkAssociation",
    "AWS::EC2::CustomerGateway",
    "AWS::EC2::DHCPOptions",
    "AWS::EC2::EC2Fleet",
    "AWS::EC2::EIP",
    "AWS::EC2::EIPAssociation",
    "AWS::EC2::EgressOnlyInternetGateway",
    "AWS::EC2::EnclaveCertificateIamRoleAssociation",
    "AWS::EC2::FlowLog",
    "AWS::EC2::GatewayRouteTableAssociation",
    "AWS::EC2::Host",
    "AWS::EC2::IPAM",
    "AWS::EC2::IPAMAllocation",
    "AWS::EC2::IPAMPool",
    "AWS::EC2::IPAMPoolCidr",
    "AWS::EC2::IPAMResourceDiscovery",
    "AWS::EC2::IPAMResourceDiscoveryAssociation",
    "AWS::EC2::IPAMScope",
    "AWS::EC2::Instance",
    "AWS::EC2::InstanceConnectEndpoint",
    "AWS::EC2::InternetGateway",
    "AWS::EC2::KeyPair",
    "AWS::EC2::LaunchTemplate",
    "AWS::EC2::LocalGatewayRoute",
    "AWS::EC2::LocalGatewayRouteTable",
    "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
    "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation",
    "AWS::EC2::NatGateway",
    "AWS::EC2::NetworkAcl",
    "AWS::EC2::NetworkAclEntry",
    "AWS::EC2::NetworkInsightsAccessScope",
    "AWS::EC2::NetworkInsightsAccessScopeAnalysis",
    "AWS::EC2::NetworkInsightsAnalysis",
    "AWS::EC2::NetworkInsightsPath",
    "AWS::EC2::NetworkInterface",
    "AWS::EC2::NetworkInterfaceAttachment",
    "AWS::EC2::NetworkInterfacePermission",
    "AWS::EC2::NetworkPerformanceMetricSubscription",
    "AWS::EC2::PlacementGroup",
    "AWS::EC2::PrefixList",
    "AWS::EC2::Route",
    "AWS::EC2::RouteTable",
    "AWS::EC2::SecurityGroup",
    "AWS::EC2::SecurityGroupEgress",
    "AWS::EC2::SecurityGroupIngress",
    "AWS::EC2::SecurityGroupVpcAssociation",
    "AWS::EC2::SnapshotBlockPublicAccess",
    "AWS::EC2::SpotFleet",
    "AWS::EC2::Subnet",
    "AWS::EC2::SubnetCidrBlock",
    "AWS::EC2::SubnetNetworkAclAssociation",
    "AWS::EC2::SubnetRouteTableAssociation",
    "AWS::EC2::TrafficMirrorFilter",
    "AWS::EC2::TrafficMirrorFilterRule",
    "AWS::EC2::TrafficMirrorSession",
    "AWS::EC2::TrafficMirrorTarget",
    "AWS::EC2::TransitGateway",
    "AWS::EC2::TransitGatewayAttachment",
    "AWS::EC2::TransitGatewayConnect",
    "AWS::EC2::TransitGatewayMulticastDomain",
    "AWS::EC2::TransitGatewayMulticastDomainAssociation",
    "AWS::EC2::TransitGatewayMulticastGroupMember",
    "AWS::EC2::TransitGatewayMulticastGroupSource",
    "AWS::EC2::TransitGatewayPeeringAttachment",
    "AWS::EC2::TransitGatewayRoute",
    "AWS::EC2::TransitGatewayRouteTable",
    "AWS::EC2::TransitGatewayRouteTableAssociation",
    "AWS::EC2::TransitGatewayRouteTablePropagation",
    "AWS::EC2::TransitGatewayVpcAttachment",
    "AWS::EC2::VPC",
    "AWS::EC2::VPCBlockPublicAccessExclusion",
    "AWS::EC2::VPCBlockPublicAccessOptions",
    "AWS::EC2::VPCCidrBlock",
    "AWS::EC2::VPCDHCPOptionsAssociation",
    "AWS::EC2::VPCEndpoint",
    "AWS::EC2::VPCEndpointConnectionNotification",
    "AWS::EC2::VPCEndpointService",
    "AWS::EC2::VPCEndpointServicePermissions",
    "AWS::EC2::VPCGatewayAttachment",
    "AWS::EC2::VPCPeeringConnection",
    "AWS::EC2::VPNConnection",
    "AWS::EC2::VPNConnectionRoute",
    "AWS::EC2::VPNGateway",
    "AWS::EC2::VPNGatewayRoutePropagation",
    "AWS::EC2::VerifiedAccessEndpoint",
    "AWS::EC2::VerifiedAccessGroup",
    "AWS::EC2::VerifiedAccessInstance",
    "AWS::EC2::VerifiedAccessTrustProvider",
    "AWS::EC2::Volume",
    "AWS::EC2::VolumeAttachment",
    "AWS::ECR::PullThroughCacheRule",
    "AWS::ECR::RegistryPolicy",
    "AWS::ECR::ReplicationConfiguration",
    "AWS::ECR::Repository",
    "AWS::ECR::RepositoryCreationTemplate",
    "AWS::ECS::CapacityProvider",
    "AWS::ECS::Cluster",
    "AWS::ECS::ClusterCapacityProviderAssociations",
    "AWS::ECS::PrimaryTaskSet",
    "AWS::ECS::Service",
    "AWS::ECS::TaskDefinition",
    "AWS::ECS::TaskSet",
    "AWS::EFS::AccessPoint",
    "AWS::EFS::FileSystem",
    "AWS::EFS::MountTarget",
    "AWS::EKS::AccessEntry",
    "AWS::EKS::Addon",
    "AWS::EKS::Cluster",
    "AWS::EKS::FargateProfile",
    "AWS::EKS::IdentityProviderConfig",
    "AWS::EKS::Nodegroup",
    "AWS::EKS::PodIdentityAssociation",
    "AWS::EMR::Cluster",
    "AWS::EMR::InstanceFleetConfig",
    "AWS::EMR::InstanceGroupConfig",
    "AWS::EMR::SecurityConfiguration",
    "AWS::EMR::Step",
    "AWS::EMR::Studio",
    "AWS::EMR::StudioSessionMapping",
    "AWS::EMRContainers::VirtualCluster",
    "AWS::EMRServerless::Application",
    "AWS::ElastiCache::CacheCluster",
    "AWS::ElastiCache::GlobalReplicationGroup",
    "AWS::ElastiCache::ParameterGroup",
    "AWS::ElastiCache::ReplicationGroup",
    "AWS::ElastiCache::SecurityGroup",
    "AWS::ElastiCache::SecurityGroupIngress",
    "AWS::ElastiCache::ServerlessCache",
    "AWS::ElastiCache::SubnetGroup",
    "AWS::ElastiCache::User",
    "AWS::ElastiCache::UserGroup",
    "AWS::ElasticBeanstalk::Application",
    "AWS::ElasticBeanstalk::ApplicationVersion",
    "AWS::ElasticBeanstalk::ConfigurationTemplate",
    "AWS::ElasticBeanstalk::Environment",
    "AWS::ElasticLoadBalancing::LoadBalancer",
    "AWS::ElasticLoadBalancingV2::Listener",
    "AWS::ElasticLoadBalancingV2::ListenerCertificate",
    "AWS::ElasticLoadBalancingV2::ListenerRule",
    "AWS::ElasticLoadBalancingV2::LoadBalancer",
    "AWS::ElasticLoadBalancingV2::TargetGroup",
    "AWS::ElasticLoadBalancingV2::TrustStore",
    "AWS::ElasticLoadBalancingV2::TrustStoreRevocation",
    "AWS::Elasticsearch::Domain",
    "AWS::EventSchemas::Discoverer",
    "AWS::EventSchemas::Registry",
    "AWS::EventSchemas::RegistryPolicy",
    "AWS::EventSchemas::Schema",
    "AWS::Events::ApiDestination",
    "AWS::Events::Archive",
    "AWS::Events::Connection",
    "AWS::Events::Endpoint",
    "AWS::Events::EventBus",
    "AWS::Events::EventBusPolicy",
    "AWS::Events::Rule",
    "AWS::FIS::ExperimentTemplate",
    "AWS::FIS::TargetAccountConfiguration",
    "AWS::FMS::NotificationChannel",
    "AWS::FMS::Policy",
    "AWS::FMS::ResourceSet",
    "AWS::FSx::DataRepositoryAssociation",
    "AWS::FSx::FileSystem",
    "AWS::FSx::Snapshot",
    "AWS::FSx::StorageVirtualMachine",
    "AWS::FSx::Volume",
    "AWS::FinSpace::Environment",
    "AWS::GameLift::Alias",
    "AWS::GameLift::Build",
    "AWS::GameLift::Fleet",
    "AWS::GameLift::GameServerGroup",
    "AWS::GameLift::GameSessionQueue",
    "AWS::GameLift::Location",
    "AWS::GameLift::MatchmakingConfiguration",
    "AWS::GameLift::MatchmakingRuleSet",
    "AWS::GameLift::Script",
    "AWS::GlobalAccelerator::Accelerator",
    "AWS::GlobalAccelerator::CrossAccountAttachment",
    "AWS::GlobalAccelerator::EndpointGroup",
    "AWS::GlobalAccelerator::Listener",
    "AWS::Glue::Classifier",
    "AWS::Glue::Connection",
    "AWS::Glue::Crawler",
    "AWS::Glue::CustomEntityType",
    "AWS::Glue::DataCatalogEncryptionSettings",
    "AWS::Glue::DataQualityRuleset",
    "AWS::Glue::Database",
    "AWS::Glue::DevEndpoint",
    "AWS::Glue::Job",
    "AWS::Glue::MLTransform",
    "AWS::Glue::Partition",
    "AWS::Glue::Registry",
    "AWS::Glue::Schema",
    "AWS::Glue::SchemaVersion",
    "AWS::Glue::SchemaVersionMetadata",
    "AWS::Glue::SecurityConfiguration",
    "AWS::Glue::Table",
    "AWS::Glue::TableOptimizer",
    "AWS::Glue::Trigger",
    "AWS::Glue::UsageProfile",
    "AWS::Glue::Workflow",
    "AWS::GreengrassV2::ComponentVersion",
    "AWS::GreengrassV2::Deployment",
    "AWS::GuardDuty::Detector",
    "AWS::GuardDuty::Filter",
    "AWS::GuardDuty::IPSet",
    "AWS::GuardDuty::MalwareProtectionPlan",
    "AWS::GuardDuty::Master",
    "AWS::GuardDuty::Member",
    "AWS::GuardDuty::PublishingDestination",
    "AWS::GuardDuty::ThreatIntelSet",
    "AWS::IAM::AccessKey",
    "AWS::IAM::Group",
    "AWS::IAM::GroupPolicy",
    "AWS::IAM::InstanceProfile",
    "AWS::IAM::ManagedPolicy",
    "AWS::IAM::OIDCProvider",
    "AWS::IAM::Policy",
    "AWS::IAM::Role",
    "AWS::IAM::RolePolicy",
    "AWS::IAM::SAMLProvider",
    "AWS::IAM::ServerCertificate",
    "AWS::IAM::ServiceLinkedRole",
    "AWS::IAM::User",
    "AWS::IAM::UserPolicy",
    "AWS::IAM::UserToGroupAddition",
    "AWS::IAM::VirtualMFADevice",
    "AWS::IdentityStore::Group",
    "AWS::IdentityStore::GroupMembership",
    "AWS::ImageBuilder::Component",
    "AWS::ImageBuilder::ContainerRecipe",
    "AWS::ImageBuilder::DistributionConfiguration",
    "AWS::ImageBuilder::Image",
    "AWS::ImageBuilder::ImagePipeline",
    "AWS::ImageBuilder::ImageRecipe",
    "AWS::ImageBuilder::InfrastructureConfiguration",
    "AWS::ImageBuilder::LifecyclePolicy",
    "AWS::ImageBuilder::Workflow",
    "AWS::InspectorV2::CisScanConfiguration",
    "AWS::InspectorV2::Filter",
    "AWS::InternetMonitor::Monitor",
    "AWS::Invoicing::InvoiceUnit",
    "AWS::IoT::AccountAuditConfiguration",
    "AWS::IoT::Authorizer",
    "AWS::IoT::BillingGroup",
    "AWS::IoT::CACertificate",
    "AWS::IoT::Certificate",
    "AWS::IoT::CertificateProvider",
    "AWS::IoT::Command",
    "AWS::IoT::CustomMetric",
    "AWS::IoT::Dimension",
    "AWS::IoT::DomainConfiguration",
    "AWS::IoT::FleetMetric",
    "AWS::IoT::JobTemplate",
    "AWS::IoT::Logging",
    "AWS::IoT::MitigationAction",
    "AWS::IoT::Policy",
    "AWS::IoT::PolicyPrincipalAttachment",
    "AWS::IoT::ProvisioningTemplate",
    "AWS::IoT::ResourceSpecificLogging",
    "AWS::IoT::RoleAlias",
    "AWS::IoT::ScheduledAudit",
    "AWS::IoT::SecurityProfile",
    "AWS::IoT::SoftwarePackage",
    "AWS::IoT::SoftwarePackageVersion",
    "AWS::IoT::Thing",
    "AWS::IoT::ThingGroup",
    "AWS::IoT::ThingPrincipalAttachment",
    "AWS::IoT::ThingType",
    "AWS::IoT::TopicRule",
    "AWS::IoT::TopicRuleDestination",
    "AWS::IoTEvents::AlarmModel",
    "AWS::IoTEvents::DetectorModel",
    "AWS::IoTEvents::Input",
    "AWS::IoTFleetHub::Application",
    "AWS::IoTSiteWise::AccessPolicy",
    "AWS::IoTSiteWise::Asset",
    "AWS::IoTSiteWise::AssetModel",
    "AWS::IoTSiteWise::Dashboard",
    "AWS::IoTSiteWise::Gateway",
    "AWS::IoTSiteWise::Portal",
    "AWS::IoTSiteWise::Project",
    "AWS::KMS::Alias",
    "AWS::KMS::Key",
    "AWS::KMS::ReplicaKey",
    "AWS::KafkaConnect::Connector",
    "AWS::KafkaConnect::CustomPlugin",
    "AWS::KafkaConnect::WorkerConfiguration",
    "AWS::Kendra::DataSource",
    "AWS::Kendra::Faq",
    "AWS::Kendra::Index",
    "AWS::KendraRanking::ExecutionPlan",
    "AWS::Kinesis::ResourcePolicy",
    "AWS::Kinesis::Stream",
    "AWS::Kinesis::StreamConsumer",
    "AWS::KinesisAnalytics::Application",
    "AWS::KinesisAnalytics::ApplicationOutput",
    "AWS::KinesisAnalytics::ApplicationReferenceDataSource",
    "AWS::KinesisAnalyticsV2::Application",
    "AWS::KinesisAnalyticsV2::ApplicationCloudWatchLoggingOption",
    "AWS::KinesisAnalyticsV2::ApplicationOutput",
    "AWS::KinesisAnalyticsV2::ApplicationReferenceDataSource",
    "AWS::KinesisFirehose::DeliveryStream",
    "AWS::KinesisVideo::SignalingChannel",
    "AWS::KinesisVideo::Stream",
    "AWS::LakeFormation::DataCellsFilter",
    "AWS::LakeFormation::DataLakeSettings",
    "AWS::LakeFormation::Permissions",
    "AWS::LakeFormation::PrincipalPermissions",
    "AWS::LakeFormation::Resource",
    "AWS::LakeFormation::Tag",
    "AWS::LakeFormation::TagAssociation",
    "AWS::Lambda::Alias",
    "AWS::Lambda::CodeSigningConfig",
    "AWS::Lambda::EventInvokeConfig",
    "AWS::Lambda::EventSourceMapping",
    "AWS::Lambda::Function",
    "AWS::Lambda::LayerVersion",
    "AWS::Lambda::LayerVersionPermission",
    "AWS::Lambda::Permission",
    "AWS::Lambda::Url",
    "AWS::Lambda::Version",
    "AWS::LaunchWizard::Deployment",
    "AWS::Lex::Bot",
    "AWS::Lex::BotAlias",
    "AWS::Lex::BotVersion",
    "AWS::Lex::ResourcePolicy",
    "AWS::LicenseManager::Grant",
    "AWS::LicenseManager::License",
    "AWS::Lightsail::Alarm",
    "AWS::Lightsail::Bucket",
    "AWS::Lightsail::Certificate",
    "AWS::Lightsail::Container",
    "AWS::Lightsail::Database",
    "AWS::Lightsail::Disk",
    "AWS::Lightsail::Instance",
    "AWS::Lightsail::LoadBalancer",
    "AWS::Lightsail::LoadBalancerTlsCertificate",
    "AWS::Lightsail::StaticIp",
    "AWS::Location::APIKey",
    "AWS::Location::GeofenceCollection",
    "AWS::Location::Map",
    "AWS::Location::PlaceIndex",
    "AWS::Location::RouteCalculator",
    "AWS::Location::Tracker",
    "AWS::Location::TrackerConsumer",
    "AWS::Logs::AccountPolicy",
    "AWS::Logs::Delivery",
    "AWS::Logs::DeliveryDestination",
    "AWS::Logs::DeliverySource",
    "AWS::Logs::Destination",
    "AWS::Logs::Integration",
    "AWS::Logs::LogAnomalyDetector",
    "AWS::Logs::LogGroup",
    "AWS::Logs::LogStream",
    "AWS::Logs::MetricFilter",
    "AWS::Logs::QueryDefinition",
    "AWS::Logs::ResourcePolicy",
    "AWS::Logs::SubscriptionFilter",
    "AWS::Logs::Transformer",
    "AWS::M2::Application",
    "AWS::M2::Deployment",
    "AWS::M2::Environment",
    "AWS::MSK::BatchScramSecret",
    "AWS::MSK::Cluster",
    "AWS::MSK::ClusterPolicy",
    "AWS::MSK::Configuration",
    "AWS::MSK::Replicator",
    "AWS::MSK::ServerlessCluster",
    "AWS::MSK::VpcConnection",
    "AWS::MWAA::Environment",
    "AWS::Macie::AllowList",
    "AWS::Macie::CustomDataIdentifier",
    "AWS::Macie::FindingsFilter",
    "AWS::Macie::Session",
    "AWS::MediaConnect::Bridge",
    "AWS::MediaConnect::BridgeOutput",
    "AWS::MediaConnect::BridgeSource",
    "AWS::MediaConnect::Flow",
    "AWS::MediaConnect::FlowEntitlement",
    "AWS::MediaConnect::FlowOutput",
    "AWS::MediaConnect::FlowSource",
    "AWS::MediaConnect::FlowVpcInterface",
    "AWS::MediaConnect::Gateway",
    "AWS::MediaConvert::JobTemplate",
    "AWS::MediaConvert::Preset",
    "AWS::MediaConvert::Queue",
    "AWS::MediaLive::CloudWatchAlarmTemplate",
    "AWS::MediaLive::CloudWatchAlarmTemplateGroup",
    "AWS::MediaLive::EventBridgeRuleTemplate",
    "AWS::MediaLive::EventBridgeRuleTemplateGroup",
    "AWS::MediaLive::Multiplex",
    "AWS::MediaLive::Multiplexprogram",
    "AWS::MediaLive::SignalMap",
    "AWS::MediaPackage::Asset",
    "AWS::MediaPackage::Channel",
    "AWS::MediaPackage::OriginEndpoint",
    "AWS::MediaPackage::PackagingConfiguration",
    "AWS::MediaPackage::PackagingGroup",
    "AWS::MediaPackageV2::Channel",
    "AWS::MediaPackageV2::ChannelGroup",
    "AWS::MediaPackageV2::ChannelPolicy",
    "AWS::MediaPackageV2::OriginEndpoint",
    "AWS::MediaPackageV2::OriginEndpointPolicy",
    "AWS::MediaTailor::Channel",
    "AWS::MediaTailor::ChannelPolicy",
    "AWS::MediaTailor::LiveSource",
    "AWS::MediaTailor::PlaybackConfiguration",
    "AWS::MediaTailor::SourceLocation",
    "AWS::MediaTailor::VodSource",
    "AWS::MemoryDB::ACL",
    "AWS::MemoryDB::Cluster",
    "AWS::MemoryDB::ParameterGroup",
    "AWS::MemoryDB::SubnetGroup",
    "AWS::MemoryDB::User",
    "AWS::Neptune::DBCluster",
    "AWS::Neptune::DBClusterParameterGroup",
    "AWS::Neptune::DBInstance",
    "AWS::Neptune::DBParameterGroup",
    "AWS::Neptune::DBSubnetGroup",
    "AWS::Neptune::EventSubscription",
    "AWS::NetworkFirewall::Firewall",
    "AWS::NetworkFirewall::FirewallPolicy",
    "AWS::NetworkFirewall::LoggingConfiguration",
    "AWS::NetworkFirewall::RuleGroup",
    "AWS::NetworkFirewall::TLSInspectionConfiguration",
    "AWS::NetworkManager::ConnectAttachment",
    "AWS::NetworkManager::ConnectPeer",
    "AWS::NetworkManager::CoreNetwork",
    "AWS::NetworkManager::CustomerGatewayAssociation",
    "AWS::NetworkManager::Device",
    "AWS::NetworkManager::DirectConnectGatewayAttachment",
    "AWS::NetworkManager::GlobalNetwork",
    "AWS::NetworkManager::Link",
    "AWS::NetworkManager::LinkAssociation",
    "AWS::NetworkManager::Site",
    "AWS::NetworkManager::SiteToSiteVpnAttachment",
    "AWS::NetworkManager::TransitGatewayPeering",
    "AWS::NetworkManager::TransitGatewayRegistration",
    "AWS::NetworkManager::TransitGatewayRouteTableAttachment",
    "AWS::NetworkManager::VpcAttachment",
    "AWS::OSIS::Pipeline",
    "AWS::Oam::Link",
    "AWS::Oam::Sink",
    "AWS::OpenSearchServerless::AccessPolicy",
    "AWS::OpenSearchServerless::Collection",
    "AWS::OpenSearchServerless::Index",
    "AWS::OpenSearchServerless::LifecyclePolicy",
    "AWS::OpenSearchServerless::SecurityConfig",
    "AWS::OpenSearchServerless::SecurityPolicy",
    "AWS::OpenSearchServerless::VpcEndpoint",
    "AWS::OpenSearchService::Application",
    "AWS::OpenSearchService::Domain",
    "AWS::OpsWorks::App",
    "AWS::OpsWorks::ElasticLoadBalancerAttachment",
    "AWS::OpsWorks::Instance",
    "AWS::OpsWorks::Layer",
    "AWS::OpsWorks::Stack",
    "AWS::OpsWorks::UserProfile",
    "AWS::OpsWorks::Volume",
    "AWS::Organizations::Account",
    "AWS::Organizations::Organization",
    "AWS::Organizations::OrganizationalUnit",
    "AWS::Organizations::Policy",
    "AWS::Organizations::ResourcePolicy",
    "AWS::PCAConnectorAD::Connector",
    "AWS::PCAConnectorAD::DirectoryRegistration",
    "AWS::PCAConnectorAD::ServicePrincipalName",
    "AWS::PCAConnectorAD::Template",
    "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
    "AWS::PCAConnectorSCEP::Challenge",
    "AWS::PCAConnectorSCEP::Connector",
    "AWS::Panorama::ApplicationInstance",
    "AWS::Panorama::Package",
    "AWS::Panorama::PackageVersion",
    "AWS::Personalize::Dataset",
    "AWS::Personalize::DatasetGroup",
    "AWS::Personalize::Schema",
    "AWS::Personalize::Solution",
    "AWS::Pinpoint::ADMChannel",
    "AWS::Pinpoint::APNSChannel",
    "AWS::Pinpoint::APNSSandboxChannel",
    "AWS::Pinpoint::APNSVoipChannel",
    "AWS::Pinpoint::APNSVoipSandboxChannel",
    "AWS::Pinpoint::App",
    "AWS::Pinpoint::ApplicationSettings",
    "AWS::Pinpoint::BaiduChannel",
    "AWS::Pinpoint::Campaign",
    "AWS::Pinpoint::EmailChannel",
    "AWS::Pinpoint::EmailTemplate",
    "AWS::Pinpoint::EventStream",
    "AWS::Pinpoint::GCMChannel",
    "AWS::Pinpoint::InAppTemplate",
    "AWS::Pinpoint::PushTemplate",
    "AWS::Pinpoint::SMSChannel",
    "AWS::Pinpoint::Segment",
    "AWS::Pinpoint::SmsTemplate",
    "AWS::Pinpoint::VoiceChannel",
    "AWS::Pipes::Pipe",
    "AWS::Proton::EnvironmentAccountConnection",
    "AWS::Proton::EnvironmentTemplate",
    "AWS::Proton::ServiceTemplate",
    "AWS::QLDB::Stream",
    "AWS::QuickSight::Analysis",
    "AWS::QuickSight::CustomPermissions",
    "AWS::QuickSight::Dashboard",
    "AWS::QuickSight::DataSet",
    "AWS::QuickSight::DataSource",
    "AWS::QuickSight::Folder",
    "AWS::QuickSight::RefreshSchedule",
    "AWS::QuickSight::Template",
    "AWS::QuickSight::Theme",
    "AWS::QuickSight::Topic",
    "AWS::QuickSight::VPCConnection",
    "AWS::RAM::Permission",
    "AWS::RAM::ResourceShare",
    "AWS::RDS::CustomDBEngineVersion",
    "AWS::RDS::DBCluster",
    "AWS::RDS::DBClusterParameterGroup",
    "AWS::RDS::DBInstance",
    "AWS::RDS::DBParameterGroup",
    "AWS::RDS::DBProxy",
    "AWS::RDS::DBProxyEndpoint",
    "AWS::RDS::DBProxyTargetGroup",
    "AWS::RDS::DBSecurityGroup",
    "AWS::RDS::DBSecurityGroupIngress",
    "AWS::RDS::DBSubnetGroup",
    "AWS::RDS::EventSubscription",
    "AWS::RDS::GlobalCluster",
    "AWS::RDS::Integration",
    "AWS::RDS::OptionGroup",
    "AWS::RUM::AppMonitor",
    "AWS::Rbin::Rule",
    "AWS::Redshift::Cluster",
    "AWS::Redshift::ClusterParameterGroup",
    "AWS::Redshift::ClusterSecurityGroup",
    "AWS::Redshift::ClusterSecurityGroupIngress",
    "AWS::Redshift::ClusterSubnetGroup",
    "AWS::Redshift::EndpointAccess",
    "AWS::Redshift::EndpointAuthorization",
    "AWS::Redshift::EventSubscription",
    "AWS::Redshift::Integration",
    "AWS::Redshift::ScheduledAction",
    "AWS::RedshiftServerless::Namespace",
    "AWS::RedshiftServerless::Workgroup",
    "AWS::RefactorSpaces::Application",
    "AWS::RefactorSpaces::Environment",
    "AWS::RefactorSpaces::Route",
    "AWS::RefactorSpaces::Service",
    "AWS::Rekognition::Collection",
    "AWS::ResilienceHub::App",
    "AWS::ResilienceHub::ResiliencyPolicy",
    "AWS::ResourceExplorer2::DefaultViewAssociation",
    "AWS::ResourceExplorer2::Index",
    "AWS::ResourceExplorer2::View",
    "AWS::ResourceGroups::Group",
    "AWS::ResourceGroups::TagSyncTask",
    "AWS::RolesAnywhere::CRL",
    "AWS::RolesAnywhere::Profile",
    "AWS::RolesAnywhere::TrustAnchor",
    "AWS::Route53::CidrCollection",
    "AWS::Route53::DNSSEC",
    "AWS::Route53::HealthCheck",
    "AWS::Route53::HostedZone",
    "AWS::Route53::KeySigningKey",
    "AWS::Route53::RecordSet",
    "AWS::Route53::RecordSetGroup",
    "AWS::Route53Profiles::Profile",
    "AWS::Route53Profiles::ProfileAssociation",
    "AWS::Route53Profiles::ProfileResourceAssociation",
    "AWS::Route53Resolver::FirewallDomainList",
    "AWS::Route53Resolver::FirewallRuleGroup",
    "AWS::Route53Resolver::FirewallRuleGroupAssociation",
    "AWS::Route53Resolver::OutpostResolver",
    "AWS::Route53Resolver::ResolverConfig",
    "AWS::Route53Resolver::ResolverDNSSECConfig",
    "AWS::Route53Resolver::ResolverEndpoint",
    "AWS::Route53Resolver::ResolverQueryLoggingConfig",
    "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation",
    "AWS::Route53Resolver::ResolverRule",
    "AWS::Route53Resolver::ResolverRuleAssociation",
    "AWS::S3::AccessGrant",
    "AWS::S3::AccessGrantsInstance",
    "AWS::S3::AccessGrantsLocation",
    "AWS::S3::AccessPoint",
    "AWS::S3::Bucket",
    "AWS::S3::BucketPolicy",
    "AWS::S3::MultiRegionAccessPoint",
    "AWS::S3::MultiRegionAccessPointPolicy",
    "AWS::S3::StorageLens",
    "AWS::S3::StorageLensGroup",
    "AWS::S3ObjectLambda::AccessPoint",
    "AWS::S3ObjectLambda::AccessPointPolicy",
    "AWS::S3Outposts::AccessPoint",
    "AWS::S3Outposts::Bucket",
    "AWS::S3Outposts::BucketPolicy",
    "AWS::S3Outposts::Endpoint",
    "AWS::S3Tables::TableBucket",
    "AWS::S3Tables::TableBucketPolicy",
    "AWS::SDB::Domain",
    "AWS::SES::ConfigurationSet",
    "AWS::SES::ConfigurationSetEventDestination",
    "AWS::SES::ContactList",
    "AWS::SES::DedicatedIpPool",
    "AWS::SES::EmailIdentity",
    "AWS::SES::MailManagerAddonInstance",
    "AWS::SES::MailManagerAddonSubscription",
    "AWS::SES::MailManagerArchive",
    "AWS::SES::MailManagerIngressPoint",
    "AWS::SES::MailManagerRelay",
    "AWS::SES::MailManagerRuleSet",
    "AWS::SES::MailManagerTrafficPolicy",
    "AWS::SES::ReceiptFilter",
    "AWS::SES::ReceiptRule",
    "AWS::SES::ReceiptRuleSet",
    "AWS::SES::Template",
    "AWS::SES::VdmAttributes",
    "AWS::SNS::Subscription",
    "AWS::SNS::Topic",
    "AWS::SNS::TopicInlinePolicy",
    "AWS::SNS::TopicPolicy",
    "AWS::SQS::Queue",
    "AWS::SQS::QueueInlinePolicy",
    "AWS::SQS::QueuePolicy",
    "AWS::SSM::Association",
    "AWS::SSM::Document",
    "AWS::SSM::MaintenanceWindow",
    "AWS::SSM::MaintenanceWindowTarget",
    "AWS::SSM::MaintenanceWindowTask",
    "AWS::SSM::Parameter",
    "AWS::SSM::PatchBaseline",
    "AWS::SSM::ResourceDataSync",
    "AWS::SSM::ResourcePolicy",
    "AWS::SSMContacts::Contact",
    "AWS::SSMContacts::ContactChannel",
    "AWS::SSMContacts::Plan",
    "AWS::SSMContacts::Rotation",
    "AWS::SSMIncidents::ReplicationSet",
    "AWS::SSMIncidents::ResponsePlan",
    "AWS::SSMQuickSetup::ConfigurationManager",
    "AWS::SSO::Application",
    "AWS::SSO::ApplicationAssignment",
    "AWS::SSO::Assignment",
    "AWS::SSO::Instance",
    "AWS::SSO::InstanceAccessControlAttributeConfiguration",
    "AWS::SSO::PermissionSet",
    "AWS::SageMaker::App",
    "AWS::SageMaker::AppImageConfig",
    "AWS::SageMaker::CodeRepository",
    "AWS::SageMaker::DataQualityJobDefinition",
    "AWS::SageMaker::Domain",
    "AWS::SageMaker::Endpoint",
    "AWS::SageMaker::EndpointConfig",
    "AWS::SageMaker::FeatureGroup",
    "AWS::SageMaker::Image",
    "AWS::SageMaker::ImageVersion",
    "AWS::SageMaker::InferenceComponent",
    "AWS::SageMaker::InferenceExperiment",
    "AWS::SageMaker::MlflowTrackingServer",
    "AWS::SageMaker::Model",
    "AWS::SageMaker::ModelBiasJobDefinition",
    "AWS::SageMaker::ModelCard",
    "AWS::SageMaker::ModelExplainabilityJobDefinition",
    "AWS::SageMaker::ModelPackage",
    "AWS::SageMaker::ModelPackageGroup",
    "AWS::SageMaker::ModelQualityJobDefinition",
    "AWS::SageMaker::MonitoringSchedule",
    "AWS::SageMaker::NotebookInstance",
    "AWS::SageMaker::NotebookInstanceLifecycleConfig",
    "AWS::SageMaker::PartnerApp",
    "AWS::SageMaker::Pipeline",
    "AWS::SageMaker::Project",
    "AWS::SageMaker::Space",
    "AWS::SageMaker::StudioLifecycleConfig",
    "AWS::SageMaker::UserProfile",
    "AWS::SageMaker::Workteam",
    "AWS::Scheduler::Schedule",
    "AWS::Scheduler::ScheduleGroup",
    "AWS::SecretsManager::ResourcePolicy",
    "AWS::SecretsManager::RotationSchedule",
    "AWS::SecretsManager::Secret",
    "AWS::SecretsManager::SecretTargetAttachment",
    "AWS::SecurityHub::AutomationRule",
    "AWS::SecurityHub::ConfigurationPolicy",
    "AWS::SecurityHub::DelegatedAdmin",
    "AWS::SecurityHub::FindingAggregator",
    "AWS::SecurityHub::Hub",
    "AWS::SecurityHub::Insight",
    "AWS::SecurityHub::OrganizationConfiguration",
    "AWS::SecurityHub::PolicyAssociation",
    "AWS::SecurityHub::ProductSubscription",
    "AWS::SecurityHub::SecurityControl",
    "AWS::SecurityHub::Standard",
    "AWS::SecurityLake::AwsLogSource",
    "AWS::SecurityLake::DataLake",
    "AWS::SecurityLake::Subscriber",
    "AWS::SecurityLake::SubscriberNotification",
    "AWS::ServiceCatalog::AcceptedPortfolioShare",
    "AWS::ServiceCatalog::CloudFormationProduct",
    "AWS::ServiceCatalog::CloudFormationProvisionedProduct",
    "AWS::ServiceCatalog::LaunchNotificationConstraint",
    "AWS::ServiceCatalog::LaunchRoleConstraint",
    "AWS::ServiceCatalog::LaunchTemplateConstraint",
    "AWS::ServiceCatalog::Portfolio",
    "AWS::ServiceCatalog::PortfolioPrincipalAssociation",
    "AWS::ServiceCatalog::PortfolioProductAssociation",
    "AWS::ServiceCatalog::PortfolioShare",
    "AWS::ServiceCatalog::ResourceUpdateConstraint",
    "AWS::ServiceCatalog::ServiceAction",
    "AWS::ServiceCatalog::ServiceActionAssociation",
    "AWS::ServiceCatalog::StackSetConstraint",
    "AWS::ServiceCatalog::TagOption",
    "AWS::ServiceCatalog::TagOptionAssociation",
    "AWS::ServiceCatalogAppRegistry::Application",
    "AWS::ServiceCatalogAppRegistry::AttributeGroup",
    "AWS::ServiceCatalogAppRegistry::AttributeGroupAssociation",
    "AWS::ServiceCatalogAppRegistry::ResourceAssociation",
    "AWS::ServiceDiscovery::HttpNamespace",
    "AWS::ServiceDiscovery::Instance",
    "AWS::ServiceDiscovery::PrivateDnsNamespace",
    "AWS::ServiceDiscovery::PublicDnsNamespace",
    "AWS::ServiceDiscovery::Service",
    "AWS::Shield::DRTAccess",
    "AWS::Shield::ProactiveEngagement",
    "AWS::Shield::Protection",
    "AWS::Shield::ProtectionGroup",
    "AWS::Signer::ProfilePermission",
    "AWS::Signer::SigningProfile",
    "AWS::StepFunctions::Activity",
    "AWS::StepFunctions::StateMachine",
    "AWS::StepFunctions::StateMachineAlias",
    "AWS::StepFunctions::StateMachineVersion",
    "AWS::SupportApp::AccountAlias",
    "AWS::SupportApp::SlackChannelConfiguration",
    "AWS::SupportApp::SlackWorkspaceConfiguration",
    "AWS::Synthetics::Canary",
    "AWS::Synthetics::Group",
    "AWS::SystemsManagerSAP::Application",
    "AWS::Timestream::InfluxDBInstance",
    "AWS::Transfer::Agreement",
    "AWS::Transfer::Certificate",
    "AWS::Transfer::Connector",
    "AWS::Transfer::Profile",
    "AWS::Transfer::Server",
    "AWS::Transfer::User",
    "AWS::Transfer::WebApp",
    "AWS::Transfer::Workflow",
    "AWS::VerifiedPermissions::IdentitySource",
    "AWS::VerifiedPermissions::Policy",
    "AWS::VerifiedPermissions::PolicyStore",
    "AWS::VerifiedPermissions::PolicyTemplate",
    "AWS::VoiceID::Domain",
    "AWS::VpcLattice::AccessLogSubscription",
    "AWS::VpcLattice::AuthPolicy",
    "AWS::VpcLattice::Listener",
    "AWS::VpcLattice::ResourceConfiguration",
    "AWS::VpcLattice::ResourceGateway",
    "AWS::VpcLattice::ResourcePolicy",
    "AWS::VpcLattice::Rule",
    "AWS::VpcLattice::Service",
    "AWS::VpcLattice::ServiceNetwork",
    "AWS::VpcLattice::ServiceNetworkResourceAssociation",
    "AWS::VpcLattice::ServiceNetworkServiceAssociation",
    "AWS::VpcLattice::ServiceNetworkVpcAssociation",
    "AWS::VpcLattice::TargetGroup",
    "AWS::WAF::ByteMatchSet",
    "AWS::WAF::IPSet",
    "AWS::WAF::Rule",
    "AWS::WAF::SizeConstraintSet",
    "AWS::WAF::SqlInjectionMatchSet",
    "AWS::WAF::WebACL",
    "AWS::WAF::XssMatchSet",
    "AWS::WAFRegional::ByteMatchSet",
    "AWS::WAFRegional::GeoMatchSet",
    "AWS::WAFRegional::IPSet",
    "AWS::WAFRegional::RateBasedRule",
    "AWS::WAFRegional::RegexPatternSet",
    "AWS::WAFRegional::Rule",
    "AWS::WAFRegional::SizeConstraintSet",
    "AWS::WAFRegional::SqlInjectionMatchSet",
    "AWS::WAFRegional::WebACL",
    "AWS::WAFRegional::WebACLAssociation",
    "AWS::WAFRegional::XssMatchSet",
    "AWS::WAFv2::IPSet",
    "AWS::WAFv2::LoggingConfiguration",
    "AWS::WAFv2::RegexPatternSet",
    "AWS::WAFv2::RuleGroup",
    "AWS::WAFv2::WebACL",
    "AWS::WAFv2::WebACLAssociation",
    "AWS::Wisdom::AIAgent",
    "AWS::Wisdom::AIAgentVersion",
    "AWS::Wisdom::AIGuardrail",
    "AWS::Wisdom::AIGuardrailVersion",
    "AWS::Wisdom::AIPrompt",
    "AWS::Wisdom::AIPromptVersion",
    "AWS::Wisdom::Assistant",
    "AWS::Wisdom::AssistantAssociation",
    "AWS::Wisdom::KnowledgeBase",
    "AWS::Wisdom::MessageTemplate",
    "AWS::Wisdom::MessageTemplateVersion",
    "AWS::WorkSpaces::ConnectionAlias",
    "AWS::WorkSpaces::Workspace",
    "AWS::WorkSpaces::WorkspacesPool",
    "AWS::WorkSpacesThinClient::Environment",
    "AWS::WorkSpacesWeb::BrowserSettings",
    "AWS::WorkSpacesWeb::DataProtectionSettings",
    "AWS::WorkSpacesWeb::IdentityProvider",
    "AWS::WorkSpacesWeb::IpAccessSettings",
    "AWS::WorkSpacesWeb::NetworkSettings",
    "AWS::WorkSpacesWeb::Portal",
    "AWS::WorkSpacesWeb::TrustStore",
    "AWS::WorkSpacesWeb::UserAccessLoggingSettings",
    "AWS::WorkSpacesWeb::UserSettings",
    "AWS::XRay::Group",
    "AWS::XRay::ResourcePolicy",
    "AWS::XRay::SamplingRule",
    "AWS::XRay::TransactionSearchConfig",
    "Alexa::ASK::Skill",
    "Module",
]

# pylint: disable=too-many-lines
cached: list[str] = [
    "Module",
    "alexa-ask-skill.json",
    "aws-accessanalyzer-analyzer.json",
    "aws-acmpca-certificate.json",
    "aws-acmpca-certificateauthority.json",
    "aws-acmpca-certificateauthorityactivation.json",
    "aws-acmpca-permission.json",
    "aws-amazonmq-broker.json",
    "aws-amazonmq-configuration.json",
    "aws-amazonmq-configurationassociation.json",
    "aws-amplify-app.json",
    "aws-amplify-branch.json",
    "aws-amplify-domain.json",
    "aws-amplifyuibuilder-component.json",
    "aws-amplifyuibuilder-form.json",
    "aws-amplifyuibuilder-theme.json",
    "aws-apigateway-account.json",
    "aws-apigateway-apikey.json",
    "aws-apigateway-authorizer.json",
    "aws-apigateway-basepathmapping.json",
    "aws-apigateway-basepathmappingv2.json",
    "aws-apigateway-clientcertificate.json",
    "aws-apigateway-deployment.json",
    "aws-apigateway-documentationpart.json",
    "aws-apigateway-documentationversion.json",
    "aws-apigateway-domainname.json",
    "aws-apigateway-domainnameaccessassociation.json",
    "aws-apigateway-domainnamev2.json",
    "aws-apigateway-gatewayresponse.json",
    "aws-apigateway-method.json",
    "aws-apigateway-model.json",
    "aws-apigateway-requestvalidator.json",
    "aws-apigateway-resource.json",
    "aws-apigateway-restapi.json",
    "aws-apigateway-stage.json",
    "aws-apigateway-usageplan.json",
    "aws-apigateway-usageplankey.json",
    "aws-apigateway-vpclink.json",
    "aws-apigatewayv2-apigatewaymanagedoverrides.json",
    "aws-apigatewayv2-apimapping.json",
    "aws-apigatewayv2-authorizer.json",
    "aws-apigatewayv2-deployment.json",
    "aws-apigatewayv2-integration.json",
    "aws-apigatewayv2-integrationresponse.json",
    "aws-apigatewayv2-model.json",
    "aws-apigatewayv2-route.json",
    "aws-apigatewayv2-routeresponse.json",
    "aws-apigatewayv2-stage.json",
    "aws-apigatewayv2-vpclink.json",
    "aws-appconfig-application.json",
    "aws-appconfig-configurationprofile.json",
    "aws-appconfig-deployment.json",
    "aws-appconfig-deploymentstrategy.json",
    "aws-appconfig-environment.json",
    "aws-appconfig-extension.json",
    "aws-appconfig-extensionassociation.json",
    "aws-appconfig-hostedconfigurationversion.json",
    "aws-appflow-connector.json",
    "aws-appflow-connectorprofile.json",
    "aws-appflow-flow.json",
    "aws-appintegrations-application.json",
    "aws-appintegrations-dataintegration.json",
    "aws-appintegrations-eventintegration.json",
    "aws-applicationautoscaling-scalabletarget.json",
    "aws-applicationautoscaling-scalingpolicy.json",
    "aws-applicationinsights-application.json",
    "aws-applicationsignals-discovery.json",
    "aws-applicationsignals-servicelevelobjective.json",
    "aws-appmesh-gatewayroute.json",
    "aws-appmesh-mesh.json",
    "aws-appmesh-route.json",
    "aws-appmesh-virtualgateway.json",
    "aws-appmesh-virtualnode.json",
    "aws-appmesh-virtualrouter.json",
    "aws-appmesh-virtualservice.json",
    "aws-appstream-appblock.json",
    "aws-appstream-appblockbuilder.json",
    "aws-appstream-application.json",
    "aws-appstream-applicationentitlementassociation.json",
    "aws-appstream-applicationfleetassociation.json",
    "aws-appstream-directoryconfig.json",
    "aws-appstream-entitlement.json",
    "aws-appstream-fleet.json",
    "aws-appstream-stack.json",
    "aws-appstream-stackfleetassociation.json",
    "aws-appsync-api.json",
    "aws-appsync-apicache.json",
    "aws-appsync-apikey.json",
    "aws-appsync-channelnamespace.json",
    "aws-appsync-datasource.json",
    "aws-appsync-domainname.json",
    "aws-appsync-domainnameapiassociation.json",
    "aws-appsync-functionconfiguration.json",
    "aws-appsync-graphqlschema.json",
    "aws-appsync-resolver.json",
    "aws-appsync-sourceapiassociation.json",
    "aws-aps-workspace.json",
    "aws-arczonalshift-autoshiftobservernotificationstatus.json",
    "aws-arczonalshift-zonalautoshiftconfiguration.json",
    "aws-athena-datacatalog.json",
    "aws-athena-namedquery.json",
    "aws-athena-preparedstatement.json",
    "aws-athena-workgroup.json",
    "aws-auditmanager-assessment.json",
    "aws-autoscaling-autoscalinggroup.json",
    "aws-autoscaling-launchconfiguration.json",
    "aws-autoscaling-lifecyclehook.json",
    "aws-autoscaling-scalingpolicy.json",
    "aws-autoscaling-scheduledaction.json",
    "aws-autoscaling-warmpool.json",
    "aws-autoscalingplans-scalingplan.json",
    "aws-backup-backupplan.json",
    "aws-backup-backupselection.json",
    "aws-backup-backupvault.json",
    "aws-backup-framework.json",
    "aws-backup-logicallyairgappedbackupvault.json",
    "aws-backup-reportplan.json",
    "aws-backup-restoretestingplan.json",
    "aws-backup-restoretestingselection.json",
    "aws-backupgateway-hypervisor.json",
    "aws-batch-computeenvironment.json",
    "aws-batch-consumableresource.json",
    "aws-batch-jobdefinition.json",
    "aws-batch-jobqueue.json",
    "aws-batch-schedulingpolicy.json",
    "aws-bedrock-agent.json",
    "aws-bedrock-agentalias.json",
    "aws-bedrock-applicationinferenceprofile.json",
    "aws-bedrock-datasource.json",
    "aws-bedrock-flow.json",
    "aws-bedrock-flowalias.json",
    "aws-bedrock-flowversion.json",
    "aws-bedrock-guardrail.json",
    "aws-bedrock-guardrailversion.json",
    "aws-bedrock-knowledgebase.json",
    "aws-bedrock-prompt.json",
    "aws-bedrock-promptversion.json",
    "aws-budgets-budget.json",
    "aws-budgets-budgetsaction.json",
    "aws-cassandra-keyspace.json",
    "aws-cassandra-table.json",
    "aws-cassandra-type.json",
    "aws-ce-costcategory.json",
    "aws-certificatemanager-account.json",
    "aws-certificatemanager-certificate.json",
    "aws-chatbot-microsoftteamschannelconfiguration.json",
    "aws-chatbot-slackchannelconfiguration.json",
    "aws-cloud9-environmentec2.json",
    "aws-cloudformation-customresource.json",
    "aws-cloudformation-guardhook.json",
    "aws-cloudformation-hookdefaultversion.json",
    "aws-cloudformation-hooktypeconfig.json",
    "aws-cloudformation-hookversion.json",
    "aws-cloudformation-lambdahook.json",
    "aws-cloudformation-macro.json",
    "aws-cloudformation-moduledefaultversion.json",
    "aws-cloudformation-moduleversion.json",
    "aws-cloudformation-publictypeversion.json",
    "aws-cloudformation-publisher.json",
    "aws-cloudformation-resourcedefaultversion.json",
    "aws-cloudformation-resourceversion.json",
    "aws-cloudformation-stack.json",
    "aws-cloudformation-stackset.json",
    "aws-cloudformation-typeactivation.json",
    "aws-cloudformation-waitcondition.json",
    "aws-cloudformation-waitconditionhandle.json",
    "aws-cloudfront-anycastiplist.json",
    "aws-cloudfront-cachepolicy.json",
    "aws-cloudfront-cloudfrontoriginaccessidentity.json",
    "aws-cloudfront-connectiongroup.json",
    "aws-cloudfront-continuousdeploymentpolicy.json",
    "aws-cloudfront-distribution.json",
    "aws-cloudfront-distributiontenant.json",
    "aws-cloudfront-function.json",
    "aws-cloudfront-keygroup.json",
    "aws-cloudfront-keyvaluestore.json",
    "aws-cloudfront-monitoringsubscription.json",
    "aws-cloudfront-originaccesscontrol.json",
    "aws-cloudfront-originrequestpolicy.json",
    "aws-cloudfront-publickey.json",
    "aws-cloudfront-realtimelogconfig.json",
    "aws-cloudfront-responseheaderspolicy.json",
    "aws-cloudfront-streamingdistribution.json",
    "aws-cloudfront-vpcorigin.json",
    "aws-cloudtrail-channel.json",
    "aws-cloudtrail-dashboard.json",
    "aws-cloudtrail-eventdatastore.json",
    "aws-cloudtrail-resourcepolicy.json",
    "aws-cloudtrail-trail.json",
    "aws-cloudwatch-alarm.json",
    "aws-cloudwatch-anomalydetector.json",
    "aws-cloudwatch-compositealarm.json",
    "aws-cloudwatch-dashboard.json",
    "aws-cloudwatch-insightrule.json",
    "aws-cloudwatch-metricstream.json",
    "aws-codebuild-project.json",
    "aws-codebuild-reportgroup.json",
    "aws-codebuild-sourcecredential.json",
    "aws-codecommit-repository.json",
    "aws-codeconnections-connection.json",
    "aws-codedeploy-application.json",
    "aws-codedeploy-deploymentconfig.json",
    "aws-codedeploy-deploymentgroup.json",
    "aws-codepipeline-customactiontype.json",
    "aws-codepipeline-pipeline.json",
    "aws-codepipeline-webhook.json",
    "aws-codestar-githubrepository.json",
    "aws-codestarconnections-connection.json",
    "aws-codestarconnections-repositorylink.json",
    "aws-codestarconnections-syncconfiguration.json",
    "aws-codestarnotifications-notificationrule.json",
    "aws-cognito-identitypool.json",
    "aws-cognito-identitypoolprincipaltag.json",
    "aws-cognito-identitypoolroleattachment.json",
    "aws-cognito-logdeliveryconfiguration.json",
    "aws-cognito-managedloginbranding.json",
    "aws-cognito-userpool.json",
    "aws-cognito-userpoolclient.json",
    "aws-cognito-userpooldomain.json",
    "aws-cognito-userpoolgroup.json",
    "aws-cognito-userpoolidentityprovider.json",
    "aws-cognito-userpoolresourceserver.json",
    "aws-cognito-userpoolriskconfigurationattachment.json",
    "aws-cognito-userpooluicustomizationattachment.json",
    "aws-cognito-userpooluser.json",
    "aws-cognito-userpoolusertogroupattachment.json",
    "aws-comprehend-documentclassifier.json",
    "aws-comprehend-flywheel.json",
    "aws-config-aggregationauthorization.json",
    "aws-config-configrule.json",
    "aws-config-configurationaggregator.json",
    "aws-config-configurationrecorder.json",
    "aws-config-conformancepack.json",
    "aws-config-deliverychannel.json",
    "aws-config-organizationconfigrule.json",
    "aws-config-organizationconformancepack.json",
    "aws-config-remediationconfiguration.json",
    "aws-config-storedquery.json",
    "aws-connect-agentstatus.json",
    "aws-connect-approvedorigin.json",
    "aws-connect-contactflow.json",
    "aws-connect-contactflowmodule.json",
    "aws-connect-contactflowversion.json",
    "aws-connect-emailaddress.json",
    "aws-connect-evaluationform.json",
    "aws-connect-hoursofoperation.json",
    "aws-connect-instance.json",
    "aws-connect-instancestorageconfig.json",
    "aws-connect-integrationassociation.json",
    "aws-connect-phonenumber.json",
    "aws-connect-predefinedattribute.json",
    "aws-connect-prompt.json",
    "aws-connect-queue.json",
    "aws-connect-quickconnect.json",
    "aws-connect-routingprofile.json",
    "aws-connect-rule.json",
    "aws-connect-securitykey.json",
    "aws-connect-securityprofile.json",
    "aws-connect-tasktemplate.json",
    "aws-connect-user.json",
    "aws-connect-userhierarchygroup.json",
    "aws-connect-userhierarchystructure.json",
    "aws-connect-view.json",
    "aws-connect-viewversion.json",
    "aws-connectcampaigns-campaign.json",
    "aws-connectcampaignsv2-campaign.json",
    "aws-controltower-enabledbaseline.json",
    "aws-controltower-enabledcontrol.json",
    "aws-controltower-landingzone.json",
    "aws-customerprofiles-calculatedattributedefinition.json",
    "aws-customerprofiles-domain.json",
    "aws-customerprofiles-eventstream.json",
    "aws-customerprofiles-eventtrigger.json",
    "aws-customerprofiles-integration.json",
    "aws-customerprofiles-objecttype.json",
    "aws-customerprofiles-segmentdefinition.json",
    "aws-databrew-dataset.json",
    "aws-databrew-job.json",
    "aws-databrew-project.json",
    "aws-databrew-recipe.json",
    "aws-databrew-ruleset.json",
    "aws-databrew-schedule.json",
    "aws-datasync-agent.json",
    "aws-datasync-locationazureblob.json",
    "aws-datasync-locationefs.json",
    "aws-datasync-locationfsxlustre.json",
    "aws-datasync-locationfsxontap.json",
    "aws-datasync-locationfsxopenzfs.json",
    "aws-datasync-locationfsxwindows.json",
    "aws-datasync-locationhdfs.json",
    "aws-datasync-locationnfs.json",
    "aws-datasync-locationobjectstorage.json",
    "aws-datasync-locations3.json",
    "aws-datasync-locationsmb.json",
    "aws-datasync-storagesystem.json",
    "aws-datasync-task.json",
    "aws-datazone-connection.json",
    "aws-datazone-datasource.json",
    "aws-datazone-domain.json",
    "aws-datazone-environment.json",
    "aws-datazone-environmentactions.json",
    "aws-datazone-environmentblueprintconfiguration.json",
    "aws-datazone-environmentprofile.json",
    "aws-datazone-groupprofile.json",
    "aws-datazone-project.json",
    "aws-datazone-projectmembership.json",
    "aws-datazone-subscriptiontarget.json",
    "aws-datazone-userprofile.json",
    "aws-detective-graph.json",
    "aws-detective-memberinvitation.json",
    "aws-detective-organizationadmin.json",
    "aws-devopsguru-loganomalydetectionintegration.json",
    "aws-devopsguru-notificationchannel.json",
    "aws-devopsguru-resourcecollection.json",
    "aws-directoryservice-microsoftad.json",
    "aws-dlm-lifecyclepolicy.json",
    "aws-dms-certificate.json",
    "aws-dms-datamigration.json",
    "aws-dms-dataprovider.json",
    "aws-dms-endpoint.json",
    "aws-dms-eventsubscription.json",
    "aws-dms-instanceprofile.json",
    "aws-dms-migrationproject.json",
    "aws-dms-replicationconfig.json",
    "aws-dms-replicationinstance.json",
    "aws-dms-replicationsubnetgroup.json",
    "aws-dms-replicationtask.json",
    "aws-docdb-dbcluster.json",
    "aws-docdb-dbinstance.json",
    "aws-docdb-dbsubnetgroup.json",
    "aws-docdb-eventsubscription.json",
    "aws-docdbelastic-cluster.json",
    "aws-dynamodb-globaltable.json",
    "aws-dynamodb-table.json",
    "aws-ec2-capacityreservation.json",
    "aws-ec2-capacityreservationfleet.json",
    "aws-ec2-carriergateway.json",
    "aws-ec2-clientvpnauthorizationrule.json",
    "aws-ec2-clientvpnendpoint.json",
    "aws-ec2-clientvpnroute.json",
    "aws-ec2-clientvpntargetnetworkassociation.json",
    "aws-ec2-customergateway.json",
    "aws-ec2-dhcpoptions.json",
    "aws-ec2-ec2fleet.json",
    "aws-ec2-egressonlyinternetgateway.json",
    "aws-ec2-eip.json",
    "aws-ec2-eipassociation.json",
    "aws-ec2-enclavecertificateiamroleassociation.json",
    "aws-ec2-flowlog.json",
    "aws-ec2-gatewayroutetableassociation.json",
    "aws-ec2-host.json",
    "aws-ec2-instance.json",
    "aws-ec2-instanceconnectendpoint.json",
    "aws-ec2-internetgateway.json",
    "aws-ec2-ipam.json",
    "aws-ec2-ipamallocation.json",
    "aws-ec2-ipampool.json",
    "aws-ec2-ipampoolcidr.json",
    "aws-ec2-ipamresourcediscovery.json",
    "aws-ec2-ipamresourcediscoveryassociation.json",
    "aws-ec2-ipamscope.json",
    "aws-ec2-keypair.json",
    "aws-ec2-launchtemplate.json",
    "aws-ec2-localgatewayroute.json",
    "aws-ec2-localgatewayroutetable.json",
    "aws-ec2-localgatewayroutetablevirtualinterfacegroupassociation.json",
    "aws-ec2-localgatewayroutetablevpcassociation.json",
    "aws-ec2-natgateway.json",
    "aws-ec2-networkacl.json",
    "aws-ec2-networkaclentry.json",
    "aws-ec2-networkinsightsaccessscope.json",
    "aws-ec2-networkinsightsaccessscopeanalysis.json",
    "aws-ec2-networkinsightsanalysis.json",
    "aws-ec2-networkinsightspath.json",
    "aws-ec2-networkinterface.json",
    "aws-ec2-networkinterfaceattachment.json",
    "aws-ec2-networkinterfacepermission.json",
    "aws-ec2-networkperformancemetricsubscription.json",
    "aws-ec2-placementgroup.json",
    "aws-ec2-prefixlist.json",
    "aws-ec2-route.json",
    "aws-ec2-routetable.json",
    "aws-ec2-securitygroup.json",
    "aws-ec2-securitygroupegress.json",
    "aws-ec2-securitygroupingress.json",
    "aws-ec2-securitygroupvpcassociation.json",
    "aws-ec2-snapshotblockpublicaccess.json",
    "aws-ec2-spotfleet.json",
    "aws-ec2-subnet.json",
    "aws-ec2-subnetcidrblock.json",
    "aws-ec2-subnetnetworkaclassociation.json",
    "aws-ec2-subnetroutetableassociation.json",
    "aws-ec2-trafficmirrorfilter.json",
    "aws-ec2-trafficmirrorfilterrule.json",
    "aws-ec2-trafficmirrorsession.json",
    "aws-ec2-trafficmirrortarget.json",
    "aws-ec2-transitgateway.json",
    "aws-ec2-transitgatewayattachment.json",
    "aws-ec2-transitgatewayconnect.json",
    "aws-ec2-transitgatewaymulticastdomain.json",
    "aws-ec2-transitgatewaymulticastdomainassociation.json",
    "aws-ec2-transitgatewaymulticastgroupmember.json",
    "aws-ec2-transitgatewaymulticastgroupsource.json",
    "aws-ec2-transitgatewaypeeringattachment.json",
    "aws-ec2-transitgatewayroute.json",
    "aws-ec2-transitgatewayroutetable.json",
    "aws-ec2-transitgatewayroutetableassociation.json",
    "aws-ec2-transitgatewayroutetablepropagation.json",
    "aws-ec2-transitgatewayvpcattachment.json",
    "aws-ec2-verifiedaccessendpoint.json",
    "aws-ec2-verifiedaccessgroup.json",
    "aws-ec2-verifiedaccessinstance.json",
    "aws-ec2-verifiedaccesstrustprovider.json",
    "aws-ec2-volume.json",
    "aws-ec2-volumeattachment.json",
    "aws-ec2-vpc.json",
    "aws-ec2-vpcblockpublicaccessexclusion.json",
    "aws-ec2-vpcblockpublicaccessoptions.json",
    "aws-ec2-vpccidrblock.json",
    "aws-ec2-vpcdhcpoptionsassociation.json",
    "aws-ec2-vpcendpoint.json",
    "aws-ec2-vpcendpointconnectionnotification.json",
    "aws-ec2-vpcendpointservice.json",
    "aws-ec2-vpcendpointservicepermissions.json",
    "aws-ec2-vpcgatewayattachment.json",
    "aws-ec2-vpcpeeringconnection.json",
    "aws-ec2-vpnconnection.json",
    "aws-ec2-vpnconnectionroute.json",
    "aws-ec2-vpngateway.json",
    "aws-ec2-vpngatewayroutepropagation.json",
    "aws-ecr-pullthroughcacherule.json",
    "aws-ecr-registrypolicy.json",
    "aws-ecr-replicationconfiguration.json",
    "aws-ecr-repository.json",
    "aws-ecr-repositorycreationtemplate.json",
    "aws-ecs-capacityprovider.json",
    "aws-ecs-cluster.json",
    "aws-ecs-clustercapacityproviderassociations.json",
    "aws-ecs-primarytaskset.json",
    "aws-ecs-service.json",
    "aws-ecs-taskdefinition.json",
    "aws-ecs-taskset.json",
    "aws-efs-accesspoint.json",
    "aws-efs-filesystem.json",
    "aws-efs-mounttarget.json",
    "aws-eks-accessentry.json",
    "aws-eks-addon.json",
    "aws-eks-cluster.json",
    "aws-eks-fargateprofile.json",
    "aws-eks-identityproviderconfig.json",
    "aws-eks-nodegroup.json",
    "aws-eks-podidentityassociation.json",
    "aws-elasticache-cachecluster.json",
    "aws-elasticache-globalreplicationgroup.json",
    "aws-elasticache-parametergroup.json",
    "aws-elasticache-replicationgroup.json",
    "aws-elasticache-securitygroup.json",
    "aws-elasticache-securitygroupingress.json",
    "aws-elasticache-serverlesscache.json",
    "aws-elasticache-subnetgroup.json",
    "aws-elasticache-user.json",
    "aws-elasticache-usergroup.json",
    "aws-elasticbeanstalk-application.json",
    "aws-elasticbeanstalk-applicationversion.json",
    "aws-elasticbeanstalk-configurationtemplate.json",
    "aws-elasticbeanstalk-environment.json",
    "aws-elasticloadbalancing-loadbalancer.json",
    "aws-elasticloadbalancingv2-listener.json",
    "aws-elasticloadbalancingv2-listenercertificate.json",
    "aws-elasticloadbalancingv2-listenerrule.json",
    "aws-elasticloadbalancingv2-loadbalancer.json",
    "aws-elasticloadbalancingv2-targetgroup.json",
    "aws-elasticloadbalancingv2-truststore.json",
    "aws-elasticloadbalancingv2-truststorerevocation.json",
    "aws-elasticsearch-domain.json",
    "aws-emr-cluster.json",
    "aws-emr-instancefleetconfig.json",
    "aws-emr-instancegroupconfig.json",
    "aws-emr-securityconfiguration.json",
    "aws-emr-step.json",
    "aws-emr-studio.json",
    "aws-emr-studiosessionmapping.json",
    "aws-emrcontainers-virtualcluster.json",
    "aws-emrserverless-application.json",
    "aws-events-apidestination.json",
    "aws-events-archive.json",
    "aws-events-connection.json",
    "aws-events-endpoint.json",
    "aws-events-eventbus.json",
    "aws-events-eventbuspolicy.json",
    "aws-events-rule.json",
    "aws-eventschemas-discoverer.json",
    "aws-eventschemas-registry.json",
    "aws-eventschemas-registrypolicy.json",
    "aws-eventschemas-schema.json",
    "aws-finspace-environment.json",
    "aws-fis-experimenttemplate.json",
    "aws-fis-targetaccountconfiguration.json",
    "aws-fms-notificationchannel.json",
    "aws-fms-policy.json",
    "aws-fms-resourceset.json",
    "aws-fsx-datarepositoryassociation.json",
    "aws-fsx-filesystem.json",
    "aws-fsx-snapshot.json",
    "aws-fsx-storagevirtualmachine.json",
    "aws-fsx-volume.json",
    "aws-gamelift-alias.json",
    "aws-gamelift-build.json",
    "aws-gamelift-fleet.json",
    "aws-gamelift-gameservergroup.json",
    "aws-gamelift-gamesessionqueue.json",
    "aws-gamelift-location.json",
    "aws-gamelift-script.json",
    "aws-globalaccelerator-accelerator.json",
    "aws-globalaccelerator-crossaccountattachment.json",
    "aws-globalaccelerator-endpointgroup.json",
    "aws-globalaccelerator-listener.json",
    "aws-glue-classifier.json",
    "aws-glue-connection.json",
    "aws-glue-crawler.json",
    "aws-glue-customentitytype.json",
    "aws-glue-database.json",
    "aws-glue-datacatalogencryptionsettings.json",
    "aws-glue-dataqualityruleset.json",
    "aws-glue-devendpoint.json",
    "aws-glue-job.json",
    "aws-glue-mltransform.json",
    "aws-glue-partition.json",
    "aws-glue-registry.json",
    "aws-glue-schema.json",
    "aws-glue-schemaversion.json",
    "aws-glue-schemaversionmetadata.json",
    "aws-glue-securityconfiguration.json",
    "aws-glue-table.json",
    "aws-glue-tableoptimizer.json",
    "aws-glue-trigger.json",
    "aws-glue-usageprofile.json",
    "aws-glue-workflow.json",
    "aws-greengrassv2-componentversion.json",
    "aws-greengrassv2-deployment.json",
    "aws-guardduty-detector.json",
    "aws-guardduty-filter.json",
    "aws-guardduty-ipset.json",
    "aws-guardduty-malwareprotectionplan.json",
    "aws-guardduty-master.json",
    "aws-guardduty-member.json",
    "aws-guardduty-publishingdestination.json",
    "aws-guardduty-threatintelset.json",
    "aws-iam-accesskey.json",
    "aws-iam-group.json",
    "aws-iam-grouppolicy.json",
    "aws-iam-instanceprofile.json",
    "aws-iam-managedpolicy.json",
    "aws-iam-oidcprovider.json",
    "aws-iam-policy.json",
    "aws-iam-role.json",
    "aws-iam-rolepolicy.json",
    "aws-iam-samlprovider.json",
    "aws-iam-servercertificate.json",
    "aws-iam-servicelinkedrole.json",
    "aws-iam-user.json",
    "aws-iam-userpolicy.json",
    "aws-iam-usertogroupaddition.json",
    "aws-iam-virtualmfadevice.json",
    "aws-identitystore-group.json",
    "aws-identitystore-groupmembership.json",
    "aws-imagebuilder-component.json",
    "aws-imagebuilder-containerrecipe.json",
    "aws-imagebuilder-distributionconfiguration.json",
    "aws-imagebuilder-image.json",
    "aws-imagebuilder-imagepipeline.json",
    "aws-imagebuilder-imagerecipe.json",
    "aws-imagebuilder-infrastructureconfiguration.json",
    "aws-imagebuilder-lifecyclepolicy.json",
    "aws-imagebuilder-workflow.json",
    "aws-inspectorv2-cisscanconfiguration.json",
    "aws-inspectorv2-filter.json",
    "aws-internetmonitor-monitor.json",
    "aws-invoicing-invoiceunit.json",
    "aws-iot-accountauditconfiguration.json",
    "aws-iot-authorizer.json",
    "aws-iot-billinggroup.json",
    "aws-iot-cacertificate.json",
    "aws-iot-certificate.json",
    "aws-iot-certificateprovider.json",
    "aws-iot-command.json",
    "aws-iot-custommetric.json",
    "aws-iot-dimension.json",
    "aws-iot-domainconfiguration.json",
    "aws-iot-fleetmetric.json",
    "aws-iot-jobtemplate.json",
    "aws-iot-logging.json",
    "aws-iot-mitigationaction.json",
    "aws-iot-policy.json",
    "aws-iot-policyprincipalattachment.json",
    "aws-iot-provisioningtemplate.json",
    "aws-iot-resourcespecificlogging.json",
    "aws-iot-rolealias.json",
    "aws-iot-scheduledaudit.json",
    "aws-iot-securityprofile.json",
    "aws-iot-softwarepackage.json",
    "aws-iot-softwarepackageversion.json",
    "aws-iot-thing.json",
    "aws-iot-thinggroup.json",
    "aws-iot-thingprincipalattachment.json",
    "aws-iot-thingtype.json",
    "aws-iot-topicrule.json",
    "aws-iot-topicruledestination.json",
    "aws-iotevents-alarmmodel.json",
    "aws-iotevents-detectormodel.json",
    "aws-iotevents-input.json",
    "aws-iotfleethub-application.json",
    "aws-iotsitewise-accesspolicy.json",
    "aws-iotsitewise-asset.json",
    "aws-iotsitewise-assetmodel.json",
    "aws-iotsitewise-dashboard.json",
    "aws-iotsitewise-gateway.json",
    "aws-iotsitewise-portal.json",
    "aws-iotsitewise-project.json",
    "aws-kafkaconnect-connector.json",
    "aws-kafkaconnect-customplugin.json",
    "aws-kafkaconnect-workerconfiguration.json",
    "aws-kendra-datasource.json",
    "aws-kendra-faq.json",
    "aws-kendra-index.json",
    "aws-kendraranking-executionplan.json",
    "aws-kinesis-resourcepolicy.json",
    "aws-kinesis-stream.json",
    "aws-kinesis-streamconsumer.json",
    "aws-kinesisanalytics-applicationoutput.json",
    "aws-kinesisanalyticsv2-application.json",
    "aws-kinesisanalyticsv2-applicationoutput.json",
    "aws-kinesisfirehose-deliverystream.json",
    "aws-kinesisvideo-signalingchannel.json",
    "aws-kinesisvideo-stream.json",
    "aws-kms-alias.json",
    "aws-kms-key.json",
    "aws-kms-replicakey.json",
    "aws-lakeformation-datacellsfilter.json",
    "aws-lakeformation-datalakesettings.json",
    "aws-lakeformation-permissions.json",
    "aws-lakeformation-principalpermissions.json",
    "aws-lakeformation-resource.json",
    "aws-lakeformation-tag.json",
    "aws-lakeformation-tagassociation.json",
    "aws-lambda-alias.json",
    "aws-lambda-codesigningconfig.json",
    "aws-lambda-eventinvokeconfig.json",
    "aws-lambda-eventsourcemapping.json",
    "aws-lambda-function.json",
    "aws-lambda-layerversion.json",
    "aws-lambda-layerversionpermission.json",
    "aws-lambda-permission.json",
    "aws-lambda-url.json",
    "aws-launchwizard-deployment.json",
    "aws-lex-bot.json",
    "aws-lex-botalias.json",
    "aws-lex-botversion.json",
    "aws-lex-resourcepolicy.json",
    "aws-licensemanager-grant.json",
    "aws-licensemanager-license.json",
    "aws-lightsail-alarm.json",
    "aws-lightsail-bucket.json",
    "aws-lightsail-certificate.json",
    "aws-lightsail-container.json",
    "aws-lightsail-database.json",
    "aws-lightsail-disk.json",
    "aws-lightsail-instance.json",
    "aws-lightsail-loadbalancer.json",
    "aws-lightsail-loadbalancertlscertificate.json",
    "aws-lightsail-staticip.json",
    "aws-location-apikey.json",
    "aws-location-geofencecollection.json",
    "aws-location-map.json",
    "aws-location-placeindex.json",
    "aws-location-routecalculator.json",
    "aws-location-tracker.json",
    "aws-location-trackerconsumer.json",
    "aws-logs-accountpolicy.json",
    "aws-logs-delivery.json",
    "aws-logs-deliverydestination.json",
    "aws-logs-deliverysource.json",
    "aws-logs-destination.json",
    "aws-logs-integration.json",
    "aws-logs-loganomalydetector.json",
    "aws-logs-logstream.json",
    "aws-logs-metricfilter.json",
    "aws-logs-querydefinition.json",
    "aws-logs-resourcepolicy.json",
    "aws-logs-subscriptionfilter.json",
    "aws-logs-transformer.json",
    "aws-m2-application.json",
    "aws-m2-deployment.json",
    "aws-m2-environment.json",
    "aws-macie-allowlist.json",
    "aws-macie-customdataidentifier.json",
    "aws-macie-findingsfilter.json",
    "aws-macie-session.json",
    "aws-mediaconnect-bridge.json",
    "aws-mediaconnect-bridgeoutput.json",
    "aws-mediaconnect-bridgesource.json",
    "aws-mediaconnect-flow.json",
    "aws-mediaconnect-flowentitlement.json",
    "aws-mediaconnect-flowoutput.json",
    "aws-mediaconnect-flowsource.json",
    "aws-mediaconnect-flowvpcinterface.json",
    "aws-mediaconnect-gateway.json",
    "aws-mediaconvert-jobtemplate.json",
    "aws-mediaconvert-preset.json",
    "aws-mediaconvert-queue.json",
    "aws-medialive-cloudwatchalarmtemplate.json",
    "aws-medialive-cloudwatchalarmtemplategroup.json",
    "aws-medialive-eventbridgeruletemplate.json",
    "aws-medialive-eventbridgeruletemplategroup.json",
    "aws-medialive-multiplex.json",
    "aws-medialive-multiplexprogram.json",
    "aws-medialive-signalmap.json",
    "aws-mediapackage-asset.json",
    "aws-mediapackage-channel.json",
    "aws-mediapackage-originendpoint.json",
    "aws-mediapackage-packagingconfiguration.json",
    "aws-mediapackage-packaginggroup.json",
    "aws-mediapackagev2-channel.json",
    "aws-mediapackagev2-channelgroup.json",
    "aws-mediapackagev2-channelpolicy.json",
    "aws-mediapackagev2-originendpoint.json",
    "aws-mediapackagev2-originendpointpolicy.json",
    "aws-mediatailor-channel.json",
    "aws-mediatailor-channelpolicy.json",
    "aws-mediatailor-livesource.json",
    "aws-mediatailor-playbackconfiguration.json",
    "aws-mediatailor-sourcelocation.json",
    "aws-mediatailor-vodsource.json",
    "aws-memorydb-acl.json",
    "aws-memorydb-cluster.json",
    "aws-memorydb-parametergroup.json",
    "aws-memorydb-subnetgroup.json",
    "aws-memorydb-user.json",
    "aws-msk-batchscramsecret.json",
    "aws-msk-cluster.json",
    "aws-msk-clusterpolicy.json",
    "aws-msk-configuration.json",
    "aws-msk-replicator.json",
    "aws-msk-serverlesscluster.json",
    "aws-msk-vpcconnection.json",
    "aws-mwaa-environment.json",
    "aws-neptune-dbcluster.json",
    "aws-neptune-dbclusterparametergroup.json",
    "aws-neptune-dbinstance.json",
    "aws-neptune-dbparametergroup.json",
    "aws-neptune-dbsubnetgroup.json",
    "aws-neptune-eventsubscription.json",
    "aws-networkfirewall-firewall.json",
    "aws-networkfirewall-firewallpolicy.json",
    "aws-networkfirewall-loggingconfiguration.json",
    "aws-networkfirewall-rulegroup.json",
    "aws-networkfirewall-tlsinspectionconfiguration.json",
    "aws-networkmanager-connectattachment.json",
    "aws-networkmanager-connectpeer.json",
    "aws-networkmanager-corenetwork.json",
    "aws-networkmanager-customergatewayassociation.json",
    "aws-networkmanager-device.json",
    "aws-networkmanager-directconnectgatewayattachment.json",
    "aws-networkmanager-globalnetwork.json",
    "aws-networkmanager-link.json",
    "aws-networkmanager-linkassociation.json",
    "aws-networkmanager-site.json",
    "aws-networkmanager-sitetositevpnattachment.json",
    "aws-networkmanager-transitgatewaypeering.json",
    "aws-networkmanager-transitgatewayregistration.json",
    "aws-networkmanager-transitgatewayroutetableattachment.json",
    "aws-networkmanager-vpcattachment.json",
    "aws-oam-link.json",
    "aws-oam-sink.json",
    "aws-opensearchserverless-accesspolicy.json",
    "aws-opensearchserverless-collection.json",
    "aws-opensearchserverless-index.json",
    "aws-opensearchserverless-lifecyclepolicy.json",
    "aws-opensearchserverless-securityconfig.json",
    "aws-opensearchserverless-securitypolicy.json",
    "aws-opensearchserverless-vpcendpoint.json",
    "aws-opensearchservice-application.json",
    "aws-opensearchservice-domain.json",
    "aws-opsworks-app.json",
    "aws-opsworks-elasticloadbalancerattachment.json",
    "aws-opsworks-instance.json",
    "aws-opsworks-layer.json",
    "aws-opsworks-stack.json",
    "aws-opsworks-userprofile.json",
    "aws-opsworks-volume.json",
    "aws-organizations-account.json",
    "aws-organizations-organization.json",
    "aws-organizations-organizationalunit.json",
    "aws-organizations-policy.json",
    "aws-organizations-resourcepolicy.json",
    "aws-osis-pipeline.json",
    "aws-panorama-applicationinstance.json",
    "aws-panorama-package.json",
    "aws-panorama-packageversion.json",
    "aws-pcaconnectorad-connector.json",
    "aws-pcaconnectorad-directoryregistration.json",
    "aws-pcaconnectorad-serviceprincipalname.json",
    "aws-pcaconnectorad-template.json",
    "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
    "aws-pcaconnectorscep-challenge.json",
    "aws-pcaconnectorscep-connector.json",
    "aws-personalize-dataset.json",
    "aws-personalize-datasetgroup.json",
    "aws-personalize-schema.json",
    "aws-personalize-solution.json",
    "aws-pinpoint-apnschannel.json",
    "aws-pinpoint-apnssandboxchannel.json",
    "aws-pinpoint-apnsvoipchannel.json",
    "aws-pinpoint-apnsvoipsandboxchannel.json",
    "aws-pinpoint-applicationsettings.json",
    "aws-pinpoint-campaign.json",
    "aws-pinpoint-emailchannel.json",
    "aws-pinpoint-emailtemplate.json",
    "aws-pinpoint-eventstream.json",
    "aws-pinpoint-gcmchannel.json",
    "aws-pinpoint-inapptemplate.json",
    "aws-pinpoint-pushtemplate.json",
    "aws-pinpoint-smschannel.json",
    "aws-pinpoint-smstemplate.json",
    "aws-pinpoint-voicechannel.json",
    "aws-pipes-pipe.json",
    "aws-proton-environmentaccountconnection.json",
    "aws-proton-environmenttemplate.json",
    "aws-proton-servicetemplate.json",
    "aws-qldb-stream.json",
    "aws-quicksight-analysis.json",
    "aws-quicksight-custompermissions.json",
    "aws-quicksight-dashboard.json",
    "aws-quicksight-dataset.json",
    "aws-quicksight-datasource.json",
    "aws-quicksight-folder.json",
    "aws-quicksight-refreshschedule.json",
    "aws-quicksight-template.json",
    "aws-quicksight-theme.json",
    "aws-quicksight-topic.json",
    "aws-quicksight-vpcconnection.json",
    "aws-ram-permission.json",
    "aws-ram-resourceshare.json",
    "aws-rbin-rule.json",
    "aws-rds-customdbengineversion.json",
    "aws-rds-dbcluster.json",
    "aws-rds-dbclusterparametergroup.json",
    "aws-rds-dbparametergroup.json",
    "aws-rds-dbproxy.json",
    "aws-rds-dbproxyendpoint.json",
    "aws-rds-dbproxytargetgroup.json",
    "aws-rds-dbsecuritygroup.json",
    "aws-rds-dbsecuritygroupingress.json",
    "aws-rds-dbsubnetgroup.json",
    "aws-rds-eventsubscription.json",
    "aws-rds-globalcluster.json",
    "aws-rds-integration.json",
    "aws-rds-optiongroup.json",
    "aws-redshift-cluster.json",
    "aws-redshift-clusterparametergroup.json",
    "aws-redshift-clustersecuritygroup.json",
    "aws-redshift-clustersecuritygroupingress.json",
    "aws-redshift-clustersubnetgroup.json",
    "aws-redshift-endpointaccess.json",
    "aws-redshift-endpointauthorization.json",
    "aws-redshift-eventsubscription.json",
    "aws-redshift-integration.json",
    "aws-redshift-scheduledaction.json",
    "aws-redshiftserverless-namespace.json",
    "aws-redshiftserverless-workgroup.json",
    "aws-refactorspaces-application.json",
    "aws-refactorspaces-environment.json",
    "aws-refactorspaces-route.json",
    "aws-refactorspaces-service.json",
    "aws-rekognition-collection.json",
    "aws-resiliencehub-app.json",
    "aws-resiliencehub-resiliencypolicy.json",
    "aws-resourceexplorer2-defaultviewassociation.json",
    "aws-resourceexplorer2-index.json",
    "aws-resourceexplorer2-view.json",
    "aws-resourcegroups-group.json",
    "aws-resourcegroups-tagsynctask.json",
    "aws-rolesanywhere-crl.json",
    "aws-rolesanywhere-profile.json",
    "aws-rolesanywhere-trustanchor.json",
    "aws-route53-cidrcollection.json",
    "aws-route53-dnssec.json",
    "aws-route53-healthcheck.json",
    "aws-route53-hostedzone.json",
    "aws-route53-keysigningkey.json",
    "aws-route53-recordset.json",
    "aws-route53-recordsetgroup.json",
    "aws-route53profiles-profile.json",
    "aws-route53profiles-profileassociation.json",
    "aws-route53profiles-profileresourceassociation.json",
    "aws-route53resolver-firewalldomainlist.json",
    "aws-route53resolver-firewallrulegroup.json",
    "aws-route53resolver-firewallrulegroupassociation.json",
    "aws-route53resolver-outpostresolver.json",
    "aws-route53resolver-resolverconfig.json",
    "aws-route53resolver-resolverdnssecconfig.json",
    "aws-route53resolver-resolverendpoint.json",
    "aws-route53resolver-resolverqueryloggingconfig.json",
    "aws-route53resolver-resolverqueryloggingconfigassociation.json",
    "aws-route53resolver-resolverrule.json",
    "aws-route53resolver-resolverruleassociation.json",
    "aws-rum-appmonitor.json",
    "aws-s3-accessgrant.json",
    "aws-s3-accessgrantsinstance.json",
    "aws-s3-accessgrantslocation.json",
    "aws-s3-accesspoint.json",
    "aws-s3-bucket.json",
    "aws-s3-bucketpolicy.json",
    "aws-s3-multiregionaccesspoint.json",
    "aws-s3-multiregionaccesspointpolicy.json",
    "aws-s3-storagelens.json",
    "aws-s3-storagelensgroup.json",
    "aws-s3objectlambda-accesspoint.json",
    "aws-s3objectlambda-accesspointpolicy.json",
    "aws-s3outposts-accesspoint.json",
    "aws-s3outposts-bucket.json",
    "aws-s3outposts-bucketpolicy.json",
    "aws-s3outposts-endpoint.json",
    "aws-s3tables-tablebucket.json",
    "aws-s3tables-tablebucketpolicy.json",
    "aws-sagemaker-app.json",
    "aws-sagemaker-appimageconfig.json",
    "aws-sagemaker-coderepository.json",
    "aws-sagemaker-dataqualityjobdefinition.json",
    "aws-sagemaker-domain.json",
    "aws-sagemaker-endpointconfig.json",
    "aws-sagemaker-featuregroup.json",
    "aws-sagemaker-image.json",
    "aws-sagemaker-imageversion.json",
    "aws-sagemaker-inferencecomponent.json",
    "aws-sagemaker-inferenceexperiment.json",
    "aws-sagemaker-mlflowtrackingserver.json",
    "aws-sagemaker-model.json",
    "aws-sagemaker-modelbiasjobdefinition.json",
    "aws-sagemaker-modelcard.json",
    "aws-sagemaker-modelexplainabilityjobdefinition.json",
    "aws-sagemaker-modelpackage.json",
    "aws-sagemaker-modelpackagegroup.json",
    "aws-sagemaker-modelqualityjobdefinition.json",
    "aws-sagemaker-monitoringschedule.json",
    "aws-sagemaker-notebookinstance.json",
    "aws-sagemaker-notebookinstancelifecycleconfig.json",
    "aws-sagemaker-partnerapp.json",
    "aws-sagemaker-pipeline.json",
    "aws-sagemaker-project.json",
    "aws-sagemaker-space.json",
    "aws-sagemaker-studiolifecycleconfig.json",
    "aws-sagemaker-userprofile.json",
    "aws-sagemaker-workteam.json",
    "aws-scheduler-schedule.json",
    "aws-scheduler-schedulegroup.json",
    "aws-sdb-domain.json",
    "aws-secretsmanager-resourcepolicy.json",
    "aws-secretsmanager-rotationschedule.json",
    "aws-secretsmanager-secret.json",
    "aws-secretsmanager-secrettargetattachment.json",
    "aws-securityhub-automationrule.json",
    "aws-securityhub-configurationpolicy.json",
    "aws-securityhub-delegatedadmin.json",
    "aws-securityhub-findingaggregator.json",
    "aws-securityhub-hub.json",
    "aws-securityhub-insight.json",
    "aws-securityhub-organizationconfiguration.json",
    "aws-securityhub-policyassociation.json",
    "aws-securityhub-productsubscription.json",
    "aws-securityhub-securitycontrol.json",
    "aws-securityhub-standard.json",
    "aws-securitylake-awslogsource.json",
    "aws-securitylake-datalake.json",
    "aws-securitylake-subscriber.json",
    "aws-securitylake-subscribernotification.json",
    "aws-servicecatalog-acceptedportfolioshare.json",
    "aws-servicecatalog-cloudformationproduct.json",
    "aws-servicecatalog-cloudformationprovisionedproduct.json",
    "aws-servicecatalog-launchnotificationconstraint.json",
    "aws-servicecatalog-launchroleconstraint.json",
    "aws-servicecatalog-launchtemplateconstraint.json",
    "aws-servicecatalog-portfolio.json",
    "aws-servicecatalog-portfolioprincipalassociation.json",
    "aws-servicecatalog-portfolioproductassociation.json",
    "aws-servicecatalog-portfolioshare.json",
    "aws-servicecatalog-resourceupdateconstraint.json",
    "aws-servicecatalog-serviceaction.json",
    "aws-servicecatalog-serviceactionassociation.json",
    "aws-servicecatalog-stacksetconstraint.json",
    "aws-servicecatalog-tagoption.json",
    "aws-servicecatalog-tagoptionassociation.json",
    "aws-servicecatalogappregistry-application.json",
    "aws-servicecatalogappregistry-attributegroup.json",
    "aws-servicecatalogappregistry-attributegroupassociation.json",
    "aws-servicecatalogappregistry-resourceassociation.json",
    "aws-servicediscovery-httpnamespace.json",
    "aws-servicediscovery-instance.json",
    "aws-servicediscovery-privatednsnamespace.json",
    "aws-servicediscovery-publicdnsnamespace.json",
    "aws-servicediscovery-service.json",
    "aws-ses-configurationset.json",
    "aws-ses-configurationseteventdestination.json",
    "aws-ses-contactlist.json",
    "aws-ses-dedicatedippool.json",
    "aws-ses-emailidentity.json",
    "aws-ses-mailmanageraddoninstance.json",
    "aws-ses-mailmanageraddonsubscription.json",
    "aws-ses-mailmanagerarchive.json",
    "aws-ses-mailmanageringresspoint.json",
    "aws-ses-mailmanagerrelay.json",
    "aws-ses-mailmanagerruleset.json",
    "aws-ses-mailmanagertrafficpolicy.json",
    "aws-ses-receiptfilter.json",
    "aws-ses-receiptrule.json",
    "aws-ses-receiptruleset.json",
    "aws-ses-template.json",
    "aws-ses-vdmattributes.json",
    "aws-shield-drtaccess.json",
    "aws-shield-proactiveengagement.json",
    "aws-shield-protection.json",
    "aws-shield-protectiongroup.json",
    "aws-signer-profilepermission.json",
    "aws-signer-signingprofile.json",
    "aws-sns-subscription.json",
    "aws-sns-topic.json",
    "aws-sns-topicinlinepolicy.json",
    "aws-sns-topicpolicy.json",
    "aws-sqs-queue.json",
    "aws-sqs-queueinlinepolicy.json",
    "aws-sqs-queuepolicy.json",
    "aws-ssm-association.json",
    "aws-ssm-document.json",
    "aws-ssm-maintenancewindow.json",
    "aws-ssm-maintenancewindowtarget.json",
    "aws-ssm-maintenancewindowtask.json",
    "aws-ssm-parameter.json",
    "aws-ssm-patchbaseline.json",
    "aws-ssm-resourcedatasync.json",
    "aws-ssm-resourcepolicy.json",
    "aws-ssmcontacts-contact.json",
    "aws-ssmcontacts-contactchannel.json",
    "aws-ssmcontacts-plan.json",
    "aws-ssmcontacts-rotation.json",
    "aws-ssmincidents-replicationset.json",
    "aws-ssmincidents-responseplan.json",
    "aws-ssmquicksetup-configurationmanager.json",
    "aws-sso-application.json",
    "aws-sso-applicationassignment.json",
    "aws-sso-assignment.json",
    "aws-sso-instance.json",
    "aws-sso-instanceaccesscontrolattributeconfiguration.json",
    "aws-sso-permissionset.json",
    "aws-stepfunctions-activity.json",
    "aws-stepfunctions-statemachine.json",
    "aws-stepfunctions-statemachinealias.json",
    "aws-stepfunctions-statemachineversion.json",
    "aws-supportapp-accountalias.json",
    "aws-supportapp-slackchannelconfiguration.json",
    "aws-supportapp-slackworkspaceconfiguration.json",
    "aws-synthetics-canary.json",
    "aws-synthetics-group.json",
    "aws-systemsmanagersap-application.json",
    "aws-timestream-influxdbinstance.json",
    "aws-transfer-agreement.json",
    "aws-transfer-certificate.json",
    "aws-transfer-connector.json",
    "aws-transfer-profile.json",
    "aws-transfer-server.json",
    "aws-transfer-user.json",
    "aws-transfer-webapp.json",
    "aws-transfer-workflow.json",
    "aws-verifiedpermissions-identitysource.json",
    "aws-verifiedpermissions-policy.json",
    "aws-verifiedpermissions-policystore.json",
    "aws-verifiedpermissions-policytemplate.json",
    "aws-voiceid-domain.json",
    "aws-vpclattice-accesslogsubscription.json",
    "aws-vpclattice-authpolicy.json",
    "aws-vpclattice-resourcepolicy.json",
    "aws-vpclattice-rule.json",
    "aws-vpclattice-service.json",
    "aws-vpclattice-servicenetwork.json",
    "aws-vpclattice-servicenetworkresourceassociation.json",
    "aws-vpclattice-servicenetworkserviceassociation.json",
    "aws-vpclattice-servicenetworkvpcassociation.json",
    "aws-vpclattice-targetgroup.json",
    "aws-waf-bytematchset.json",
    "aws-waf-ipset.json",
    "aws-waf-rule.json",
    "aws-waf-sizeconstraintset.json",
    "aws-waf-sqlinjectionmatchset.json",
    "aws-waf-webacl.json",
    "aws-waf-xssmatchset.json",
    "aws-wafregional-bytematchset.json",
    "aws-wafregional-regexpatternset.json",
    "aws-wafregional-sqlinjectionmatchset.json",
    "aws-wafregional-webaclassociation.json",
    "aws-wafregional-xssmatchset.json",
    "aws-wafv2-ipset.json",
    "aws-wafv2-loggingconfiguration.json",
    "aws-wafv2-regexpatternset.json",
    "aws-wafv2-rulegroup.json",
    "aws-wafv2-webacl.json",
    "aws-wafv2-webaclassociation.json",
    "aws-wisdom-aiagent.json",
    "aws-wisdom-aiagentversion.json",
    "aws-wisdom-aiguardrail.json",
    "aws-wisdom-aiguardrailversion.json",
    "aws-wisdom-aiprompt.json",
    "aws-wisdom-aipromptversion.json",
    "aws-wisdom-assistant.json",
    "aws-wisdom-assistantassociation.json",
    "aws-wisdom-knowledgebase.json",
    "aws-wisdom-messagetemplate.json",
    "aws-wisdom-messagetemplateversion.json",
    "aws-workspaces-connectionalias.json",
    "aws-workspaces-workspace.json",
    "aws-workspaces-workspacespool.json",
    "aws-workspacesthinclient-environment.json",
    "aws-workspacesweb-browsersettings.json",
    "aws-workspacesweb-dataprotectionsettings.json",
    "aws-workspacesweb-identityprovider.json",
    "aws-workspacesweb-ipaccesssettings.json",
    "aws-workspacesweb-networksettings.json",
    "aws-workspacesweb-portal.json",
    "aws-workspacesweb-truststore.json",
    "aws-workspacesweb-useraccessloggingsettings.json",
    "aws-workspacesweb-usersettings.json",
    "aws-xray-group.json",
    "aws-xray-resourcepolicy.json",
    "aws-xray-samplingrule.json",
    "aws-xray-transactionsearchconfig.json",
    "module.json",
]
